<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       orionorigin@orionorigin.com
 * @since      1.0.0
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 * @author     orionorigin <orionorigin@orionorigin.com>
 */
class PCD_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $pcd;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param string $pcd The name of this plugin.
     * @param string $version     The version of this plugin.
     */
    public function __construct($pcd, $version) {

        $this->pcd = $pcd;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Pcd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Pcd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (is_pcd_admin_screen()) {
            wp_enqueue_style($this->pcd, plugin_dir_url(__FILE__) . 'css/pcd-admin.css', array(), $this->version, 'all');
            wp_enqueue_style('admin_css', plugin_dir_url(__FILE__) . 'css/pcd-admin.css', false, '1.0.0');
            wp_enqueue_style('pcd-simplegrid', plugin_dir_url(__FILE__) . 'css/simplegrid.min.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-tooltip-css', plugin_dir_url(__FILE__) . 'css/tooltip.min.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-colorpicker-css', plugin_dir_url(__FILE__) . 'js/colorpicker/css/colorpicker.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-o-ui', plugin_dir_url(__FILE__) . 'css/UI.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-datatables-css', PCD_URL . 'admin/js/datatables/jquery.dataTables.min.css', array(), $this->version, 'all');
            wp_enqueue_style('o-flexgrid', plugin_dir_url(__FILE__) . 'css/flexiblegs.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-common', PCD_URL . 'public/css/pcd-common.css', array(), $this->version, 'all');
            wp_enqueue_style('pcd-bs-modal-css', PCD_URL . 'public/js/modal/modal.min.css', array(), $this->version, 'all');
            wp_enqueue_style('select2-css', plugin_dir_url(__FILE__) . 'css/select2.min.css', array(), $this->version, 'all');
        }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Pcd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Pcd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (is_pcd_admin_screen()) {
            wp_enqueue_script($this->pcd, plugin_dir_url(__FILE__) . 'js/pcd-admin.js', array('jquery'), $this->version, false);
            wp_enqueue_script('pcd-tabs-js', plugin_dir_url(__FILE__) . 'js/SpryTabbedPanels.min.js', array('jquery'), $this->version, false);
            wp_enqueue_script('pcd-tooltip-js', plugin_dir_url(__FILE__) . 'js/tooltip.js', array('jquery'), $this->version, false);
            wp_enqueue_script('pcd-colorpicker-js', plugin_dir_url(__FILE__) . 'js/colorpicker/js/colorpicker.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->pcd, plugin_dir_url(__FILE__) . 'js/pcd-admin.js', array('jquery', 'select2-js'), $this->version, false);
            wp_localize_script($this->pcd, 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
            wp_enqueue_script('pcd-jquery-cookie-js', plugin_dir_url(__FILE__) . 'js/jquery.cookie.min.js', array('jquery'), $this->version, false);
            wp_enqueue_script('o-admin', plugin_dir_url(__FILE__) . 'js/o-admin.js', array('jquery', 'jquery-ui-sortable'), $this->version, false);
            wp_localize_script('o-admin', 'home_url', home_url('/'));
            wp_enqueue_script('pcd-modal-js', PCD_URL . 'public/js/modal/modal.js', array('jquery'), $this->version, false);
            wp_enqueue_script('pcd-datatable-js', plugin_dir_url(__FILE__) . 'js/datatables/jquery.dataTables.min.js', array('jquery'), $this->version, false);
            wp_enqueue_script('select2-js', plugin_dir_url(__FILE__) . 'js/select2.min.js', array('jquery'), $this->version, 'all');
            wp_localize_script(
                    $this->pcd, 'layouts_object', array(
                'path' => esc_html(PCD_URL) . 'admin/layouts-image',
                    )
            );
        }

        wp_enqueue_script('o-extra-js', plugin_dir_url(__FILE__) . 'js/extra.js', array('jquery'), $this->version, 'all');
    }

    /**
     * Builds all the plugin menu and submenu
     */
    public function add_pcd_submenu() {
        global $submenu;
        if (class_exists('WooCommerce')) {
            add_menu_page('Phone Case Designer', 'Kandi', 'manage_product_terms', 'pcd-manage-dashboard', array($this, 'get_fonts_page'), esc_html(PCD_URL) . "/admin/images/kandi-dashicon.png");
            add_submenu_page('pcd-manage-dashboard', __('Fonts', 'pcd'), __('Fonts', 'pcd'), 'manage_product_terms', 'pcd-manage-fonts', array($this, 'get_fonts_page'));
            add_submenu_page('pcd-manage-dashboard', __('Cliparts', 'pcd'), __('Cliparts', 'pcd'), 'manage_product_terms', 'edit.php?post_type=pcd-cliparts', false);
            add_submenu_page('pcd-manage-dashboard', __('Configurations', 'pcd'), __('Configurations', 'pcd'), 'manage_product_terms', 'edit.php?post_type=pcd-config', false);
            add_submenu_page('pcd-manage-dashboard', __('Settings', 'pcd'), __('Settings', 'pcd'), 'manage_product_terms', 'pcd-manage-settings', array($this, 'get_settings_page'));
            add_submenu_page('pcd-manage-dashboard', __('Get Started', 'pcd'), __('Get Started', 'pcd'), 'manage_product_terms', 'pcd-about', array($this, 'get_about_page'));

//            $url = PCD_URL . 'user-manual.pdf';
//            array_push($submenu['pcd-manage-dashboard'], array('User Manual', 'manage_product_terms', $url));
        }
    }

    /**
     * Builds the fonts management page
     */
    public function get_fonts_page() {
        include_once PCD_DIR . '/includes/pcd-add-fonts.php';
        pcd_add_fonts();
    }

    /**
     * Redirects the plugin to the about page after the activation
     */
    public function pcd_redirect() {
        if (get_option('pcd_do_activation_redirect', false) && class_exists('WooCommerce')) {
            delete_option('pcd_do_activation_redirect');
            wp_safe_redirect(admin_url('admin.php?page=pcd-about'));
        }
    }

    /**
     * Gets the settings and put them in a global variable
     *
     * @global array $pcd_settings Settings
     */
    public function init_globals() {
        global $pcd_settings;
        $pcd_settings['pcd-general-options'] = get_option('pcd-general-options');
        $pcd_settings['pcd-texts-options'] = get_option('pcd-texts-options');
        $pcd_settings['pcd-images-options'] = get_option('pcd-images-options');
        $pcd_settings['pcd-designs-options'] = get_option('pcd-designs-options');
        $pcd_settings['pcd-colors-options'] = get_option('pcd-colors-options');
        $pcd_settings['pcd-output-options'] = get_option('pcd-output-options');
        $pcd_settings['pcd_social_networks'] = get_option('pcd_social_networks');
        $pcd_settings['pcd-upload-options'] = get_option('pcd-upload-options');
    }

    /**
     * Builds the about page
     */
    public function get_about_page() {
        ?>
        <div id='pcd-about-page'>
            <div class="wrap">
                <div id="features-wrap">
                    <h2 class="feature-h2"><?php esc_html_e('Getting Started', 'pcd'); ?></h2>
                    <div class="list-posts-content">
                        <div class="o-wrap o-features xl-gutter-8">
                            <div class="o-col col xl-1-3">
                                <img class="vc_single_image-img " src="<?php echo esc_html(PCD_URL . 'admin/images/features/'); ?>Pricesbasedonthedesign-19.svg">
                                <h3 class="pcd-title"><?php esc_html_e('CREATE A CUSTOM PHONE CASE', 'pcd'); ?></h3>
                                <p><?php esc_html_e('This tutorial is a step by step guide to teach you how to create a custom phone case on a woocommerce store using Kandi Phone Case Designer plugin...', 'pcd'); ?></p>
                                <a href="https://designersuiteforwp.com/documentation/kandi-phonecase-designer/getting-started-kandi/how-to-create-a-custom-product-with-our-kandi-phone-case-designer/?utm_source=Kandi%20Pro&utm_medium=cpc&utm_campaign=Kandi&utm_term=how%20to%20create%20a%20woocommerce%20custom%20product" class="button" target="_blank"><?php esc_html_e('Learn More', 'pcd'); ?></a>
                            </div>
                        </div>
                    </div>
                </div>

            </div>  
        </div>
        <?php
    }

    /**
     * Builds the settings page
     */
    public function get_settings_page() {
        if (isset($_POST['securite_nonce'])) {
            if (wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['securite_nonce'])), 'securite-nonce')) {
                $this->save_pcd_tab_options();
                global $wp_rewrite;
                $wp_rewrite->flush_rules(false);
            }
        }
        wp_enqueue_media();
        ?>
        <form method="POST">
            <div id="pcd-settings">
                <div class="wrap">
                    <h2><?php esc_html_e('Products Base Settings', 'pcd'); ?></h2>
                </div>
                <div id="TabbedPanels1" class="TabbedPanels">
                    <ul class="TabbedPanelsTabGroup ">
                        <li class="TabbedPanelsTab " tabindex="1"><span><?php esc_html_e('General', 'pcd'); ?></span> </li>
                        <li class="TabbedPanelsTab" tabindex="2"><span><?php esc_html_e('Uploads', 'pcd'); ?> </span></li>
                        <li class="TabbedPanelsTab" tabindex="3"><span><?php esc_html_e('Social Networks', 'pcd'); ?></span></li>
                        <li class="TabbedPanelsTab" tabindex="4"><span><?php esc_html_e('Outputs', 'pcd'); ?></span></li>
                        <li class="TabbedPanelsTab" tabindex="5"><span><?php esc_html_e('Colors', 'pcd'); ?></span></li>


                    </ul>

                    <div class="TabbedPanelsContentGroup">
                        <div class="TabbedPanelsContent">
                            <div class='pcd-grid pcd-grid-pad'>
                                <?php
                                $this->get_general_settings();
                                ?>
                            </div>
                        </div>
                        <div class="TabbedPanelsContent">
                            <div class='pcd-grid pcd-grid-pad'>
                                <?php
                                $this->get_uploads_settings();
                                ?>
                            </div>
                        </div>
                        <div class="TabbedPanelsContent">
                            <div class="pcd-grid pcd-grid-pad">
                                <?php
                                $this->get_social_networks_settings();
                                ?>
                            </div> 
                        </div>
                        <div class="TabbedPanelsContent">
                            <div class="pcd-grid pcd-grid-pad">
                                <?php
                                $this->get_output_settings();
                                ?>
                            </div> 
                        </div>
                        <div class="TabbedPanelsContent">
                            <div class="pcd-grid pcd-grid-pad">
                                <?php
                                $this->get_colors_settings();
                                // Get custom color palette.
                                $get_custom_palette = call_user_func(apply_filters('pcd_get_custom_palette_func', array($this, 'get_custom_palette')));
                                echo $get_custom_palette;
                                ?>
                            </div> 
                        </div>
                    </div>
                </div>
            </div>
            <input type="submit" value="<?php esc_html_e('Save', 'pcd'); ?>" class="button button-primary button-large mg-top-10-i">
        </form>
        <?php
    }

    /**
     * Save the settings
     */
    private function save_pcd_tab_options() {
        if (isset($_POST['securite_nonce'])) {
            if (wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['securite_nonce'])), 'securite-nonce')) {
                $key_table = ['pcd-general-options', 'pcd-upload-options', 'pcd_social_networks', 'pcd-output-options', 'pcd-colors-options'];
                foreach ($key_table as $value) {
                    if (isset($_POST[$value])) {
                        update_option($value, wp_unslash($_POST[$value]));
                    }
                }
                $this->init_globals();
                ?>
                <div id="message" class="updated below-h2"><p><?php esc_html_e('Settings successfully saved.', 'pcd'); ?></p></div>
                <?php
            }
        }
    }

    /**
     * pcd_get_woocommerce_page
     * @return array
     */
    private function pcd_get_woocommerce_page() {
        $woocommerce_page = array();
        array_push($woocommerce_page, get_option('woocommerce_shop_page_id'));
        array_push($woocommerce_page, get_option('woocommerce_cart_page_id'));
        array_push($woocommerce_page, get_option('woocommerce_checkout_page_id'));
        array_push($woocommerce_page, get_option('woocommerce_myaccount_page_id'));
        array_push($woocommerce_page, get_option('woocommerce_terms_page_id'));
        return $woocommerce_page;
    }

    /**
     * Get general settings of phone case designer
     */
    private function get_general_settings() {
        $options = array();

        $general_options_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd-general-options',
            'table' => 'options',
            'title' => __('General Settings', 'pcd'),
        );

        $args = array(
            'post_type' => 'page',
            'nopaging' => true,
            'exclude'=> $this->pcd_get_woocommerce_page()
        );

        $customizer_page = array(
            'title' => __('Design Page', 'pcd'),
            'desc' => __('This setting allows the plugin to locate the page where customizations are made. Please note that this page can only be accessed by our plugin and should not appear in any menu.', 'pcd'),
            'name' => 'pcd-general-options[pcd_page_id]',
            'type' => 'post-type',
            'default' => '',
            'class' => 'chosen_select_nostd',
            'args' => $args,
        );

        $hide_requirements_notices = array(
            'title' => __('Hide requirements notices', 'pcd'),
            'name' => 'pcd-general-options[hide-requirements-notices]',
            'default' => '0',
            'type' => 'radio',
            'desc' => __('This option allows you to define whether or not you want to hide the requirement notice.', 'pcd'),
            'options' => array(
                '0' => __('No', 'pcd'),
                '1' => __('Yes', 'pcd'),
            ),
            'row_class' => 'pcd_hide_requirements',
            'class' => 'chosen_select_nostd',
        );
        $hide_cart_button_for_custom_products = array(
            'title' => __('Disable add to cart button for custom products', 'pcd'),
            'name' => 'pcd-general-options[pcd-hide-cart-button]',
            'default' => '1',
            'type' => 'radio',
            'desc' => __('Whether or to hide the add to cart button for custom products on the store pages.', 'pcd'),
            'options' => array(
                '1' => __('Yes', 'pcd'),
                '0' => __('No', 'pcd'),
            ),
            'class' => 'chosen_select_nostd',
        );

        $general_options_end = array('type' => 'sectionend');

        $conflicts_options_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd_conflicts_options',
            'title' => __('Scripts management', 'pcd'),
            'table' => 'options',
        );

        $conflicts_options_end = array('type' => 'sectionend');

        array_push($options, $general_options_begin);
        array_push($options, $customizer_page);
        array_push($options, $hide_cart_button_for_custom_products);
        array_push($options, $hide_requirements_notices);
        array_push($options, $general_options_end);
        array_push($options, $conflicts_options_begin);
        array_push($options, $conflicts_options_end);

        $options = apply_filters('pcd_general_options', $options);
        echo o_admin_fields($options);
        ?>
        <input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce('securite-nonce'); ?>"/>
        <?php
    }

    /**
     * Builds the uploads settings options
     */
    private function get_uploads_settings() {

        $min_upload_w = array(
            'title' => __('Uploads min width (px)', 'pcd'),
            'desc' => __('Uploaded images minimum width', 'pcd'),
            'name' => 'pcd-upload-options[pcd-min-upload-width]',
            'type' => 'text',
            'default' => '',
        );
        $min_upload_h = array(
            'title' => __('Uploads min height (px)', 'pcd'),
            'desc' => __('Uploaded images minimum height', 'pcd'),
            'name' => 'pcd-upload-options[pcd-min-upload-height]',
            'type' => 'text',
            'default' => '',
        );
        $upl_extensions = array(
            'title' => __('Allowed uploads extensions', 'pcd'),
            'name' => 'pcd-upload-options[pcd-upl-extensions]',
            'default' => array('jpg', 'jpeg', 'png', 'gif', 'bmp', 'svg'),
            'type' => 'multiselect',
            'desc' => __('Allowed extensions for uploads', 'pcd'),
            'options' => array(
                'jpg' => __('jpg', 'pcd'),
                'jpeg' => __('jpeg', 'pcd'),
                'png' => __('png', 'pcd'),
                'gif' => __('gif', 'pcd'),
                'bmp' => __('bmp', 'pcd'),
                'svg' => __('svg', 'pcd'),
            ),
        );

        $upload_settings_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd-upload-options',
            'title' => __('Uploads Settings', 'pcd'),
            'table' => 'options',
        );

        $upload_settings_end = array(
            'type' => 'sectionend',
            'id' => 'pcd-upload-options',
        );

        $options = array();
        array_push($options, $upload_settings_begin);
        array_push($options, $min_upload_w);
        array_push($options, $min_upload_h);
        array_push($options, $upl_extensions);
        array_push($options, $upload_settings_end);
        $options = apply_filters('pcd_uploads_options', $options);
        echo o_admin_fields($options);
    }

    /**
     * Builds the social networks settings options
     */
    private function get_social_networks_settings() {
        $options = array();

        $social_networks_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd_social_networks',
            'title' => __('Social Networks Settings', 'pcd'),
            'table' => 'options',
        );

        $social_networks_end = array(
            'type' => 'sectionend',
            'id' => 'pcd_social_networks',
        );
        $facebook_app_id = array(
            'title' => __('Facebook APP ID', 'pcd'),
            'desc' => __('This setting is mandatory so the user can use facebook connect', 'pcd'),
            'name' => 'pcd_social_networks[pcd-facebook-app-id]',
            'type' => 'text',
            'default' => '',
        );
        $facebook_app_secret = array(
            'title' => __('Facebook APP secret', 'pcd'),
            'desc' => __('This setting is mandatory so the user can use facebook connect', 'pcd'),
            'name' => 'pcd_social_networks[pcd-facebook-app-secret]',
            'type' => 'text',
            'default' => '',
        );

        $instagram_app_id = array(
            'title' => __('Instagram APP ID', 'pcd'),
            'desc' => __('This setting is mandatory so the user can use instagram connect', 'pcd'),
            'name' => 'pcd_social_networks[pcd-instagram-app-id]',
            'type' => 'text',
            'default' => '',
        );

        $instagram_app_secret = array(
            'title' => __('Instagram APP secret', 'pcd'),
            'desc' => __('This setting is mandatory so the user can use instagram connect', 'pcd'),
            'name' => 'pcd_social_networks[pcd-instagram-app-secret]',
            'type' => 'text',
            'default' => '',
        );

        $facebook_redirect_url = array(
            'title' => __('Facebook Redirect URI', 'pcd'),
            'desc' => __('Valid OAuth redirection URI when setting up the Facebook app.', 'pcd'),
            'type' => 'custom',
            'callback' => array($this, 'get_facebook_redirection_url'),
        );
        $instragram_redirect_url = array(
            'title' => __('Instagram Redirect URI', 'pcd'),
            'desc' => __('Valid OAuth redirection URI when setting up the Instagram app.', 'pcd'),
            'type' => 'custom',
            'callback' => array($this, 'get_instagram_redirection_url'),
        );

        array_push($options, $social_networks_begin);
        array_push($options, $facebook_app_id);
        array_push($options, $facebook_app_secret);
        array_push($options, $facebook_redirect_url);
        array_push($options, $instagram_app_id);
        array_push($options, $instagram_app_secret);
        array_push($options, $instragram_redirect_url);
        array_push($options, $social_networks_end);
        echo o_admin_fields($options);
    }

    /**
     * Builds the output settings options
     */
    private function get_output_settings() {
        $options = array();
        $design_composition = array(
            'title' => __('Design decomposition', 'pcd'),
            'name' => 'pcd-output-options[design-composition]',
            'default' => 'yes',
            'type' => 'radio',
            'desc' => __('Enable / Disable the design details in the order.', 'pcd'),
            'options' => array(
                'no' => __('No', 'pcd'),
                'yes' => __('Yes', 'pcd'),
            ),
            'class' => 'chosen_select_nostd',
        );

        $use_order_id = array(
            'title' => __('Use order ID as zip name', 'pcd'),
            'name' => 'pcd-output-options[use-order-id-as-zip-name]',
            'default' => 'yes',
            'type' => 'radio',
            'desc' => __('This option will name each output archive using the order ID.', 'pcd'),
            'options' => array(
                'no' => __('No', 'pcd'),
                'yes' => __('Yes', 'pcd'),
            ),
            'class' => 'chosen_select_nostd',
        );

        $output_options_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd-output-options',
            'title' => __('Output Settings', 'pcd'),
            'table' => 'options',
        );

        $output_options_end = array(
            'type' => 'sectionend',
            'id' => 'pcd-output-options',
        );

        array_push($options, $output_options_begin);
        array_push($options, $design_composition);
        array_push($options, $use_order_id);
        array_push($options, $output_options_end);
        echo o_admin_fields($options);
    }

    /**
     * Builds the colors settings options
     */
    private function get_colors_settings() {
        $options = array();

        $svg_colors = array(
            'title' => __('SVG colorization', 'pcd'),
            'name' => 'pcd-colors-options[pcd-svg-colorization]',
            'default' => 'by-path',
            'type' => 'radio',
            'desc' => __('This option allows you to set how you would like the SVG files to be colorized', 'pcd'),
            'options' => array(
                'by-path' => __('Path by path', 'pcd'),
                'by-colors' => __('Color by color', 'pcd'),
                'none' => __('None', 'pcd'),
            ),
            'class' => 'chosen_select_nostd',
        );
        $colors_palette = array(
            'title' => __('Colors palette', 'pcd'),
            'name' => 'pcd-colors-options[pcd-color-palette]',
            'default' => 'unlimited',
            'type' => 'radio',
            'desc' => __('This option allows you would like your clients to use in their designs', 'pcd'),
            'options' => array(
                'unlimited' => __('Unlimited', 'pcd'),
                'custom' => __('Custom', 'pcd'),
            ),
            'class' => 'chosen_select_nostd',
        );
        $colors_options_begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd-colors-options',
            'title' => __('Colors Settings', 'pcd'),
            'table' => 'options',
        );

        $colors_options_end = array(
            'type' => 'sectionend',
            'id' => 'pcd-colors-options',
        );
        array_push($options, $colors_options_begin);
        array_push($options, $svg_colors);
        array_push($options, $colors_palette);
        array_push($options, $colors_options_end);
        echo o_admin_fields($options);
    }

    /**
     * Get facebook redirection url for social networks settings
     */
    public function get_facebook_redirection_url() {

        echo esc_html(PCD_URL . 'includes/hybridauth/?hauth.done=Facebook');
    }

    /**
     * Get instagram redirection url for social networks settings
     */
    public function get_instagram_redirection_url() {

        echo esc_html(PCD_URL . 'includes/hybridauth/?hauth.done=Instagram');
    }

    /**
     * Get colors palette for settings
     */
    private function get_custom_palette() {
        global $pcd_settings;
        $colors_options = $pcd_settings['pcd-colors-options'];
        $pcd_palette_type = get_proper_value($colors_options, 'pcd-color-palette', '');
        $palette_style = '';
        if (isset($pcd_palette_type) && 'custom' !== $pcd_palette_type) {
            $palette_style = "style='display:none;'";
        }
        $palette = get_proper_value($colors_options, 'pcd-custom-palette', '');
        $custom_palette = '<div class="block-form"><table class="form-table widefat" id="pcd-predefined-colors-options" ' . $palette_style . '>
                <tbody>
                    <tr valign="top">
                <td class="label"> Color palette <div class="o-desc">Please set the hex code of each color part of the palette</div></td>
                    
                    <td><div class="pcd-colors">';
        if (isset($palette) && is_array($palette)) {
            foreach ($palette as $color) {
                $custom_palette .= '<div>
                                    <input type="text" name="pcd-colors-options[pcd-custom-palette][]"style="background-color: ' . $color . '" value="' . $color . '" class="pcd-color">
                                        <button class="button pcd-remove-color">Remove</button>
                                </div>';
            }
        }
        $custom_palette .= '</div>
                        <button class="button mg-top-10" id="pcd-add-color">Add color</button>
                   </td>
                    </tr>
                </tbody>
   </table></div>';
        return $custom_palette;
    }

    /**
     * Alerts the administrator if the customization page is missing
     *
     * @global array $pcd_settings
     */
    public function notify_customization_page_missing() {
        global $pcd_settings;
        $options = $pcd_settings['pcd-general-options'];
        $hide_notices = get_proper_value($options, 'hide-requirements-notices', false);
        $pcd_page_id = $options['pcd_page_id'];
        $settings_url = get_bloginfo('url') . '/wp-admin/admin.php?page=pcd-manage-settings';
        if (!class_exists('WooCommerce')) {
            echo '<div class="error">
                   <p><b>Phone Case Designer:  </b>WooCommerce is not installed on your website. You will not be able to use the features of the plugin.</p>
                </div>';
        } else {
            if (empty($pcd_page_id)) {
                echo '<div class="error"> 
					<p><b>Phone Case Designer : </b>The design page is not defined. Please configure it in <a href="' . esc_html($settings_url) . '">plugin settings page</a>: .</p>
					</div>';
            }
            if (!extension_loaded('zip') && !$hide_notices) {
                echo '<div class="error">
					<p><b>Phone Case Designer : </b>ZIP extension not loaded on this server. You won\'t be able to generate zip outputs.</p>
					</div>';
            }
            if (!class_exists('Imagick') && !$hide_notices) {
                echo '<div class="error">
					<p><b>Phone Case Designer : </b>Imagick classes not installed on this server. You won\'t be able to generate cmyk outputs or handle adobe files conversion to image.</p>
					</div>';
            }
        }
    }

    /**
     * Alerts the administrator if the minimum requirements are not met
     */
    public function notify_minmimum_required_parameters() {
        global $pcd_settings;
        $general_options = get_proper_value($pcd_settings, 'pcd-general-options');
        $hide_notices = get_proper_value($general_options, 'hide-requirements-notices', false);
        if ($hide_notices) {
            return;
        }
        $message = '';
        $minimum_required_parameters = array(
            'memory_limit' => array(128, 'M'),
            'post_max_size' => array(8, 'M'),
            'upload_max_filesize' => array(32, 'M'),
        );
        foreach ($minimum_required_parameters as $key => $min_arr) {
            $defined_value = ini_get($key);
            if (!stristr($defined_value, 'G', true)) {
                $defined_value_int = str_replace($min_arr[1], '', $defined_value);
                if ($defined_value_int < $min_arr[0]) {
                    $message .= "Your PHP setting <b>$key</b> is currently set to <b>$defined_value</b>. We recommand to set this value at least to <b>" . implode('', $min_arr) . '</b> to avoid any issue with our plugin.<br>';
                }
            }
        }

        $edit_msg = __('How to fix this: You can edit your php.ini file to increase the specified variables to the recommanded values or you can ask your hosting company to make the changes for you.', 'pcd');

        if (!empty($message) && class_exists('WooCommerce')) {
            echo '<div class="error">
                   <p><b>Phone Case Designer : </b><br>' . $message . '<br>
                       <b>' . esc_html($edit_msg) . '</b></p>
                </div>';
        }

        $permalinks_structure = get_option('permalink_structure');
        if (strpos($permalinks_structure, 'index.php') !== false) {
            $message .= 'Your <a href="' . esc_url(admin_url() . 'options-permalink.php') . '">permalinks</a> structure is currently set to <b>custom</b> with index.php present in the structure. We recommand to set this value to <b>Post name</b> to avoid any issue with our plugin.<br>';
        }
        if (!empty($message) && class_exists('WooCommerce')) {
            echo '<div class="error"><p><b>Phone Case Designer :</b><br>' . $message . '</p></div>';
        }
    }

    /**
     * Get help admin notices
     */
    public function get_help_notices() {
        $screen = get_current_screen();
        if (isset($screen->base) && ( 'pcd_page_pcd-manage-fonts' === $screen->base ) && class_exists('WooCommerce')) {
            echo '<div class="pcd-info">
                   <p><b>' . __('Phone Case Designer : </b>Learn more about fonts management', 'pcd') . ' <a class="button" href="https://goo.gl/wZhfqv" target="_blank">' . __(' here', 'pcd') . '</a></p>
                </div>';
        }
    }

    /**
     * Get notice of missing parts errors
     */
    public function get_missing_models_notice() {
        $screen = get_current_screen();
        if (isset($_GET['action'])) {
            sanitize_key($_GET['action']);
        }
        if (isset($screen->post_type) && ( 'pcd-config' === $screen->post_type ) && isset($_GET['action']) && ( 'edit' === $_GET['action'] ) && isset($_GET['post'])) {
            $config_id = intval($_GET['post']);
            $metas = get_post_meta($config_id, 'pcd-metas', true);
            $models = get_proper_value($metas, 'models');
            if (!$models && class_exists('WooCommerce')) {
                echo '<div class="error pcd-error">
                   <p>This configuration has no model. Please set at least one in the devices and cases settings section of this page.</p></div>';
            } else {
                foreach ($models as $model) {
                    if (empty($model['name']) && class_exists('WooCommerce')) {
                        echo '<div class="error pcd-error">
                            <p>There is at least one model with no name in your configuration. A model need a name to work properly.</p>
                         </div>';
                        break;
                    }
                    if (empty($model['brand']) && class_exists('WooCommerce')) {
                        echo '<div class="error pcd-error">
                            <p>There is at least one model with no brand in your configuration. A model need a brand to work properly.</p>
                         </div>';
                        break;
                    }
                }
            }
        }
    }

    /**
     * Add custom mime types
     *
     * @param string $mimes Listes of mimes.
     */
    public function pcd_add_custom_mime_types($mimes) {
        return array_merge(
                $mimes, array(
            'svg' => 'image/svg+xml',
            'ttf' => 'application/x-font-ttf',
            'icc' => 'application/vnd.iccprofile',
                )
        );
    }

    /**
     * Get the max input vars number of php ini file.
     */
    public function get_max_input_vars_php_ini() {
        $total_max_normal = ini_get('max_input_vars');
        $msg = 'Your max input var is <strong>' . $total_max_normal . '</strong> but this page contains <strong>{nb}</strong> fields. You may experience a lost of data after saving. In order to fix this issue, please increase <strong>the max_input_vars</strong> value in your php.ini file.';
        ?>
        <script type="text/javascript">
            var o_max_input_vars = <?php echo esc_html($total_max_normal); ?>;
            var o_max_input_msg = "<?php echo esc_html_e($msg, 'pcd'); ?>";
        </script>         
        <?php
    }

    /**
     * Get subscription notice in dashboard.
     */
    public function pcd_get_subscription_notice() {

        if (is_pcd_admin_screen()) {

            if (!get_option('o-pcd-subscribe') && 'hide' !== get_transient('pcd-hide-notice')) {
                ?>
                <div id="subscription-notice" class="notice notice-info">
                    <div id="plug-logo-text" >
                        <img id="plug-logo" style="height:50px; width: 50px"src="<?php echo esc_html(PCD_URL); ?>/admin/images/kandi-logo.png">
                        <p> 
                <?php _e('<strong>Phone Case Designer</strong>: Sign up now to receive new releases notices and important bugs fixes <br> directly into your inbox! ', 'pcd'); ?>
                        </p>
                    </div>
                    <div id="plug-sucribe-form">
                        <input type="email" id="o_user_email" name="usermail" placeholder="<?php esc_html_e('Your email here', 'pcd'); ?>">
                        <img id="pcd-subscribe-loader" style="display:none;" src="<?php echo esc_html(PCD_URL); ?>/admin/images/loader.gif" >
                        <button id="pcd-subscribe" class="button button-primary"><?php esc_html_e('Subscribe', 'pcd'); ?></button>
                        <a id="pcd-dismiss"><?php esc_html_e('Not now', 'pcd'); ?></a>
                    </div>
                </div>
                <?php
            }
            ?>
            <div id="subscription-success-notice" class="notice notice-info is-dismissible" style="display:none;">
                <img src="<?php echo esc_html(PCD_URL); ?>/admin/images/kandi-logo.png">
                <div> <?php esc_html_e('<strong>Phone Case Designer</strong>: Thank you for subscribing! ', 'pcd'); ?></div>
            </div>
            <?php
        }
    }

    /**
     * Suscribe function.
     */
    public function pcd_subscribe() {
        if (isset($_POST['email'])) {
            $email = wp_unslash(sanitize_key($_POST['email']));
        }

        if (preg_match('#^[\w.-]+@[\w.-]+\.[a-z]{2,6}$#i', $email)) {
            $url = 'https://designersuiteforwp.com/service/osubscribe/v1/subscribe/?email=' . $email;
            $args = array('timeout' => 60);
            $response = wp_remote_get($url, $args);

            if (is_wp_error($response)) {
                $error_message = $response->get_error_message();
                echo esc_html("Something went wrong: $error_message");
                wp_die();
            }
            if (isset($response['body'])) {
                $answer = $response['body'];
                if ('true' === $answer) {
                    update_option('o-pcd-subscribe', 'subscribed');
                    echo esc_html($answer);
                } else {
                    echo esc_html($answer);
                }

                die();
            }
        } else {
            echo 'Please enter a valid email address';
            die();
        }
    }

    /**
     * Hide notice function.
     */
    public function pcd_hide_notice() {
        set_transient('pcd-hide-notice', 'hide', 2 * WEEK_IN_SECONDS);
        echo 'ok';
        die();
    }

}
