<?php
/**
 * The pcd config functionality of the plugin.
 *
 * @link       orionorigin@orionorigin.com
 * @since      1.0.0
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 */

/**
 * Contains all methods and hooks callbacks related to the user design.
 *
 * @author HL
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 * @author     orionorigin <orionorigin@orionorigin.com>
 */
class PCD_Config {

    /**
     * Save configuration data.
     *
     * @param int $post_id The id of post to save.
     */
    public function save_config($post_id) {
        $meta_key = 'pcd-metas';    
//        var_dump($_POST[$meta_key]['models'][1]);
//        die();
        if (isset($_POST['securite_nonce'])) {
            if (wp_verify_nonce($_POST['securite_nonce'], 'securite-nonce')) {
                if (isset($_POST[$meta_key])) {
                    $old_metas = get_post_meta($post_id, $meta_key, true);
                    if (empty($old_metas)) {
                        $old_metas = array();
                    }
                    $new_metas = array_replace($old_metas, $_POST[$meta_key]);
                    update_post_meta($post_id, $meta_key, $new_metas);
                }
            }
        }
    }

    /**
     * Get configuration selector on product page
     */
    public function get_product_config_selector() {
        $id = get_the_ID();

        $args = array(
            'post_type' => 'pcd-config',
            'nopaging' => true,
        );
        $configs = get_posts($args);
        $configs_ids = array('' => 'None');
        foreach ($configs as $config) {
            $configs_ids[$config->ID] = $config->post_title;
        }
        ?>
        <div id="pcd_config_data" class="show_if_simple">
        <?php
        $this->get_product_tab_row($id, $configs_ids, 'Configuration');
        ?>
        </div>
        <?php
    }

    /**
     * Get the configuration on product page.
     *
     * @param int    $pid The product id.
     * @param string $configs_ids The id of different configurations.
     * @param int    $title The configuration selector title.
     */
    private function get_product_tab_row($pid, $configs_ids, $title) {
        $begin = array(
            'type' => 'sectionbegin',
            'id' => 'pcd-metas-data',
        );

        $configurations = array(
            'title' => $title,
            'name' => "pcd-metas[$pid][config-id]",
            'type' => 'select',
            'options' => $configs_ids,
        );

        $end = array('type' => 'sectionend');
        $settings = apply_filters(
                'pcd_product_tab_settings', array(
            $begin,
            $configurations,
            $end,
                )
        );

        echo "<div class='pcd-product-config-row'>" . o_admin_fields($settings) . '</div>';
    }

    /**
     *  Set Variables product configuration form.
     *
     * @param object $loop The loop.
     * @param array  $variation_data The data of variation.
     * @param object $variation The variation.
     */
    public function get_variation_product_config_selector($loop, $variation_data, $variation) {
        $id = $variation->ID;

        $args = array(
            'post_type' => 'pcd-config',
            'nopaging' => true,
        );
        $configs = get_posts($args);
        $configs_ids = array('' => 'None');
        foreach ($configs as $config) {
            $configs_ids[$config->ID] = $config->post_title;
        }
        ?>
        <tr>
            <td>
        <?php
        $this->get_product_tab_row($id, $configs_ids, 'Configuration');
        ?>
            </td>
        </tr>
        <?php
    }

    /**
     * Get the link of duplicate post
     *
     * @param array  $actions The array of differents links.
     * @param object $post The post.
     */
    public function get_duplicate_post_link($actions, $post) {
        if ('pcd-config' === $post->post_type && current_user_can('edit_posts')) {
            $actions['duplicate'] = '<a href="admin.php?action=pcd_duplicate_config&amp;post=' . $post->ID . '&amp;duplicate_nonce=' . wp_create_nonce(basename(__FILE__)) . '" title="Duplicate this item" rel="permalink">Duplicate</a>';
        }
        return $actions;
    }

    /**
     * Function creates post duplicate as a draft and redirects then to the edit post screen.
     */
    public function pcd_duplicate_config() {
        global $wpcd;
        if (!( isset($_GET['post']) || isset($_POST['post']) || ( isset($_REQUEST['action']) && 'pcd_duplicate_config' === wp_verify_nonce(sanitize_key($_REQUEST['action'])) ) )) {
            wp_die('No post to duplicate has been supplied!');
        }

        /*
         * Nonce verification
         */
        if (!isset($_GET['duplicate_nonce']) || !wp_verify_nonce(sanitize_key($_GET['duplicate_nonce']), basename(__FILE__))) {
            return;
        }

        /*
         * get the original post id
         */
        $post_id = ( isset($_GET['post']) ? absint($_GET['post']) : absint($_POST['post']) );

        /*
         * and all the original post data then
         */
        $post = get_post($post_id);

        /*
         * if you don't want current user to be the new post author,
         * then change next couple of lines to this: $new_post_author = $post->post_author;
         */
        $current_user = wp_get_current_user();
        $new_post_author = $current_user->ID;

        /*
         * if post data exists, create the post duplicate
         */
        if (isset($post) && null !== $post) {
            /*
             * new post data array
             */
            $args = array(
                'comment_status' => $post->comment_status,
                'ping_status' => $post->ping_status,
                'post_author' => $new_post_author,
                'post_content' => $post->post_content,
                'post_excerpt' => $post->post_excerpt,
                'post_name' => $post->post_name,
                'post_parent' => $post->post_parent,
                'post_password' => $post->post_password,
                'post_status' => 'draft',
                'post_title' => $post->post_title . __(' - copy', 'pcd'),
                'post_type' => $post->post_type,
                'to_ping' => $post->to_ping,
                'menu_order' => $post->menu_order,
            );

            /*
             * insert the post by wp_insert_post() function
             */
            $new_post_id = wp_insert_post($args);

            /*
             * get all current post terms ad set them to the new post draft
             */
            $taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag").
            foreach ($taxonomies as $taxonomy) {
                $post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
                wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
            }

            /*
             * duplicate all post meta just in two SQL queries
             */
            $db = $wpcd;
            $post_meta_infos = $db->get_results("SELECT meta_key, meta_value FROM $db->postmeta WHERE post_id=$post_id");
            if (0 !== count($post_meta_infos)) {
                $sql_query = "INSERT INTO $db->postmeta (post_id, meta_key, meta_value) ";
                foreach ($post_meta_infos as $meta_info) {
                    $meta_key = $meta_info->meta_key;
                    if ('_wp_old_slug' === $meta_key) {
                        continue;
                    }
                    $meta_value = addslashes($meta_info->meta_value);
                    $sql_query_sel[] = "SELECT $new_post_id, '$meta_key', '$meta_value'";
                }
                $sql_query .= implode(' UNION ALL ', $sql_query_sel);
                $db->query($sql_query);
            }

            /*
             * finally, redirect to the edit post screen for the new draft
             */
            wp_safe_redirect(admin_url('post.php?action=edit&post=' . $new_post_id));
            exit;
        } else {
            echo esc_html('Post creation failed, could not find original post: ' . $post_id);
            wp_die();
        }
    }

    /**
     * Save config selected on variations page
     *
     * @param int $variation_id The id of variation to save.
     */
    public function save_variation_settings_fields($variation_id) {
        $meta_key = 'pcd-metas';
        if (isset($_POST[$meta_key])) {
            $variation = wc_get_product($variation_id);
            $old_metas = get_post_meta($variation->parent->id, $meta_key, true);
            if (empty($old_metas)) {
                $old_metas = array();
            }
            $new_metas = array_replace($old_metas, $_POST[$meta_key]);
            update_post_meta($variation->parent->id, $meta_key, $new_metas);
        }
    }

}
