<?php
/**
 * Pcd post types class.
 *
 * @link       orionorigin@orionorigin.com
 * @since      1.0.0
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 */

/**
 * Contains all methods and hooks callbacks related to the pcd post types.
 *
 * @author HL
 *
 * @package    Pcd
 * @subpackage Pcd/admin
 * @author     orionorigin <orionorigin@orionorigin.com>
 */
class PCD_Post_Types {

    /**
     * Register the pcd-cliparts postype.
     */
    public function register_cpt_cliparts() {

	$labels = array(
	    'name'			 => __( 'Cliparts', 'pcd' ),
	    'singular_name'		 => __( 'Cliparts', 'pcd' ),
	    'add_new'		 => __( 'New cliparts group', 'pcd' ),
	    'add_new_item'		 => __( 'New cliparts group', 'pcd' ),
	    'edit_item'		 => __( 'Edit cliparts group', 'pcd' ),
	    'new_item'		 => __( 'New cliparts group', 'pcd' ),
	    'view_item'		 => __( 'View group', 'pcd' ),
	    'not_found'		 => __( 'No cliparts group found', 'pcd' ),
	    'not_found_in_trash'	 => __( 'No cliparts group in the trash', 'pcd' ),
	    'menu_name'		 => __( 'Cliparts', 'pcd' ),
	);

	$args = array(
	    'labels'		 => $labels,
	    'hierarchical'		 => false,
	    'description'		 => 'Cliparts for the product designer',
	    'supports'		 => array( 'title' ),
	    'public'		 => false,
	    'menu_icon'		 => 'dashicons-images-alt',
	    'show_ui'		 => true,
	    'show_in_menu'		 => false,
	    'show_in_nav_menus'	 => false,
	    'publicly_queryable'	 => false,
	    'exclude_from_search'	 => true,
	    'has_archive'		 => false,
	    'query_var'		 => false,
	    'can_export'		 => true,
	);

	register_post_type( 'pcd-cliparts', $args );
    }

    /**
     * Create the pcd-cliparts metabox.
     */
    public function get_cliparts_metabox() {

	$screens = array( 'pcd-cliparts' );

	foreach ( $screens as $screen ) {

	    add_meta_box(
	    'pcd-cliparts-box', __( 'Cliparts', 'pcd' ), array( $this, 'get_cliparts_page' ), $screen
	    );
	}
    }

    /**
     * Get meta box related to pcd config post.
     */
    public function get_config_metabox() {

	$screens = array( 'pcd-config' );

	foreach ( $screens as $screen ) {
	    add_meta_box(
	    'pcd-cases-type', __( 'Cases type', 'pcd' ), array( $this, 'get_cases_type' ), $screen
	    );
	    add_meta_box(
	    'pcd-devices-and-cases-settings', __( 'Devices and cases settings', 'pcd' ), array( $this, 'get_devices_and_cases_settings' ), $screen
	    );
	    add_meta_box(
	    'pcd-text-settings', __( 'Text settings', 'pcd' ), array( $this, 'get_text_settings' ), $screen
	    );
	    add_meta_box(
	    'pcd-background-settings', __( 'Background settings', 'pcd' ), array( $this, 'get_background_settings' ), $screen
	    );
	    add_meta_box(
	    'pcd-metas-output', __( 'Output', 'pcd' ), array( $this, 'get_config_output_page' ), $screen
	    );
	}
    }

    /**
     * Register the case type
     */
    public function get_cases_type() {
	$begin = array(
	    'type'	 => 'sectionbegin',
	    'id'	 => 'pcd-cases-type-settings',
	);

	$type = array(
	    'title'		 => __( 'Cases Type', 'pcd' ),
	    'name'		 => 'pcd-metas[cases-type-settings]',
	    'type'		 => 'select',
	    'class'		 => 'pcd-cases-type',
	    'options'	 => array(
		'photo'		 => __( 'Photo case', 'pcd' ),
		'standard'	 => __( 'Standard case', 'pcd' ),
	    ),
	);


	$end		 = array( 'type' => 'sectionend' );
	$settings	 = array(
	    $begin,
	    $type,
	    $end,
	);
	echo o_admin_fields( $settings );
	?>
	<input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce( 'securite-nonce' ); ?>"/>
	<?php
    }

    /**
     * Register divices and cases settings
     *
     * @global type $o_row_templates
     */
    public function get_devices_and_cases_settings() {
	wp_enqueue_media();
	?>
	<script>
	    var pcd_admin_layouts =<?php echo wp_json_encode(pcd_get_layouts_info()); ?>;
	</script>
	<?php
	$begin = array(
	    'type'	 => 'sectionbegin',
	    'id'	 => 'pcd-devices-and-cases-settings',
	);
	global $pcd_layouts;
	pcd_get_available_layouts();

	$select_layouts	 = array(
	    'title'		 => __( 'Available layouts', 'pcd' ),
	    'name'		 => 'pcd-metas[select-layouts]',
	    'type'		 => 'multiselect',
	    'class'		 => 'select-layouts',
	    'desc'		 => __( 'Select the availabe layouts on this config', 'pcd' ),
	    'options'	 => $pcd_layouts,
	);
	global $pcd_models;
	pcd_get_available_models();
	$model		 = array(
	    'title'		 => __( 'Model', 'pcd' ),
	    'name'		 => 'pcd-metas[models]',
	    'type'		 => 'select',
	    'id'		 => 'select-model',
	    'desc'		 => __( 'Select your phone model', 'pcd' ),
	    'class'		 => 'select-model',
	    'options'	 => $pcd_models,
	);

	$end		 = array( 'type' => 'sectionend' );
	$settings	 = array(
	    $begin,
	    $model,
	    $select_layouts,
	    $end,
	);
	echo o_admin_fields( $settings );
	?>
	<input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce( 'securite-nonce' ); ?>"/>
	<?php
    }

    public function get_config_output_page() {
	$options	 = array();
	$output_format	 = array(
	    'title'		 => __( 'Output Format', 'pcd' ),
	    'name'		 => 'pcd-metas[output-settings][output-format]',
	    'type'		 => 'radio',
	    'row_class'	 => 'config-output-format',
	    'options'	 => array(
		'png'	 => __( 'PNG', 'pcd' ),
		'jpg'	 => __( 'JPG', 'pcd' ),
		'svg'	 => __( 'SVG', 'pcd' ),
	    ),
	    'default'	 => 'png',
	    'desc'		 => "choose your design output format here."
	);

	$zip_output	 = array(
	    'title'		 => __( 'Zip output file', 'pcd' ),
	    'name'		 => 'pcd-metas[output-settings][zip-output]',
	    'type'		 => 'radio',
	    'row_class'	 => 'zip-output',
	    'options'	 => array(
		'yes'	 => __( 'Yes', 'pcd' ),
		'no'	 => __( 'No', 'pcd' ),
	    ),
	    'default'	 => 'yes',
	    'desc'		 => 'Choose wether or not you want a zip as output file.'
	);
	$zip_folder_name = array(
	    'title'		 => __( 'Zip output folder prefix', 'pcd' ),
	    'name'		 => 'pcd-metas[output-settings][zip-folder-name]',
	    'type'		 => 'text',
	    'row_class'	 => 'show-if-zip',
	);

	$output_options_begin = array(
	    'type'	 => 'sectionbegin',
	    'title'	 => __( 'Output Settings', 'pcd' ),
	    'table'	 => 'metas',
	    'id'	 => 'wpc_product_output',
	);

	$output_options_end = array(
	    'type'	 => 'sectionend',
	    'id'	 => 'wpc_product_output',
	);

	array_push( $options, $output_options_begin );
	array_push( $options, $output_format );
	array_push( $options, $zip_output );
	array_push( $options, $zip_folder_name );
	array_push( $options, $output_options_end );
	?>

	<?php
	echo o_admin_fields( $options );
	global $o_row_templates;
	?>
	<script>
	    var o_rows_tpl = <?php echo json_encode( $o_row_templates ); ?>;
	</script>
	<?php
    }

    /**
     * Register custom color palette
     *
     * @param type $post_id
     * @return string
     */

    private function get_custom_palette( $post_id ) {
	$pcd_metas		 = get_post_meta( $post_id, 'pcd-metas', true );
	$pcd_palette_type	 = get_proper_value( $pcd_metas, 'colors-palette-type', '' );
	$custom_palette		 = '';
	if ( isset( $pcd_palette_type ) && 'palette' === $pcd_palette_type ) {
	    $palette_style_palette	 = '';
	    $palette_style_default	 = "style='display:none;'";
	} elseif ( isset( $pcd_palette_type ) && 'picker' === $pcd_palette_type ) {

	    $palette_style_palette	 = "style='display:none;'";
	    $palette_style_default	 = '';
	} else {
	    $palette_style_palette	 = "style='display:none;'";
	    $palette_style_default	 = '';
	}
	$palette_hex	 = get_proper_value( $pcd_metas, 'pcd-custom-palette-hex', '' );
	$palette_name	 = get_proper_value( $pcd_metas, 'pcd-custom-palette-name', '' );
	$custom_palette	 = '
                    <tr id="pcd-predefined-colors-options" ' . $palette_style_palette . '>
                <td class="label"> Color palette <div class="o-desc">Please set the hex code of each color part of the palette</div></td>
                  <td>  <div class="pcd-colors">';
	if ( isset( $palette_hex ) && is_array( $palette_hex ) && isset( $palette_name ) && is_array( $palette_name ) ) {
	    foreach ( $palette_hex as $key => $color ) {
		$custom_palette .= '<table><tr>
                                   <td><input type="text" name="pcd-metas[pcd-custom-palette-name][]" value="' . $palette_name[ $key ] . '" class="pcd-meta-custom-palette-name">
                                  <input type="text" name="pcd-metas[pcd-custom-palette-hex][]"style="background-color: ' . $color . '" value="' . $color . '" class="pcd-meta-custom-palette-hex">
                                        <button class="button pcd-remove-color">Remove</button></td>
                                </td></table>';
	    }
	}
	$custom_palette .= '</div>
                        <button class="button mg-top-10" id="pcd-add-color">Add color</button>
                    </td>

                    </tr>';

	$default_color = get_proper_value( $pcd_metas, 'pcd-default-color', '' );

	$custom_palette .= '
                    <tr id="pcd-default-color" ' . $palette_style_default . '>
                ';
	if ( isset( $default_color ) ) {

	    $custom_palette .= '
                                    
                                   <td class="label">Default color hexadecimal code</td>
                                   <td><input type="text" placeholder="Click here" name="pcd-metas[pcd-default-color]"style="background-color: ' . $default_color . '" value="' . $default_color . '" class="pcd-meta-custom-palette-hex"></td>
                                        
                                ';
	}
	$custom_palette .= '
                        
                    
                    </tr>';

	return $custom_palette;
    }

    /**
     * Register text settings
     */
    public function get_text_settings() {
	$begin = array(
	    'type'	 => 'sectionbegin',
	    'id'	 => 'pcd-text-settings',
	);

	$use_global_fonts = array(
	    'title'		 => __( 'Use global fonts', 'pcd' ),
	    'name'		 => 'pcd-metas[use-global-fonts]',
	    'type'		 => 'select',
	    'id'		 => 'pcd-use-global-fonts',
	    'options'	 => array(
		'yes'	 => __( 'Yes', 'pcd' ),
		'no'	 => __( 'No', 'pcd' ),
	    ),
	);

	$fonts = get_option( 'pcd-fonts' );

	$display_fonts = array();
	if ( is_array( $fonts ) ) {
	    foreach ( $fonts as $font ) {
		if ( isset( $font[ 0 ] ) && ! empty( $font[ 0 ] ) ) {
		    $display_fonts[ wp_json_encode( $font ) ] = __( $font[ 0 ], 'pcd' );
		}
	    }
	}

	$select_font = array(
	    'title'		 => __( 'Select fonts', 'pcd' ),
	    'name'		 => 'pcd-metas[select-fonts]',
	    'type'		 => 'multiselect',
	    'id'		 => 'select-fonts',
	    'desc'		 => __( 'Select usable fonts on this configuration', 'pcd' ),
	    'options'	 => $display_fonts,
	);

	$max_length		 = array(
	    'title'	 => __( 'Max length', 'pcd' ),
	    'name'	 => 'pcd-metas[max-length]',
	    'type'	 => 'number',
	);
	$colors_palette_type	 = array(
	    'title'		 => __( 'Colors palette type', 'pcd' ),
	    'name'		 => 'pcd-metas[colors-palette-type]',
	    'desc'		 => __( 'Choose your colors palette type', 'pcd' ),
	    'type'		 => 'select',
	    'class'		 => 'pcd-colors-palette-type',
	    'options'	 => array(
		'picker'	 => __( 'Color picker ', 'pcd' ),
		'palette'	 => __( 'Predefined color palette', 'pcd' ),
	    ),
	);

	$end		 = array( 'type' => 'sectionend' );
	$settings	 = array(
	    $begin,
	    $use_global_fonts,
	    $select_font,
	    $max_length,
	    $colors_palette_type,
	    $end,
	);
	$content	 = explode( "</tbody>", o_admin_fields( $settings ) )[ 0 ] . $this->get_custom_palette( get_the_ID() ) . "</tbody></table></div></div></div>";
	echo $content;
	?>
	<input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce( 'securite-nonce' ); ?>"/>
	<?php
    }

    /**
     * Register background settings
     */
    public function get_background_settings() {
	$begin = array(
	    'type'	 => 'sectionbegin',
	    'id'	 => 'pcd-background-settings',
	);


	$cliparts = get_posts(
	[
	    'post_type'	 => 'pcd-cliparts',
	    'post_status'	 => 'publish',
	    'numberposts'	 => -1,
	]
	);

	$display_background = array();
	foreach ( $cliparts as $clipart ) {
	    if ( isset( $clipart->ID ) && ! empty( $clipart->ID ) && isset( $clipart->post_title ) && ! empty( $clipart->post_title ) ) {

		$display_background[ $clipart->ID . '-' . $clipart->post_title ] = __( $clipart->post_title, 'pcd' );
	    }
	}

	$select_background = array(
	    'title'		 => __( ' Background categories', 'pcd' ),
	    'name'		 => 'pcd-metas[select-background]',
	    'id'		 => 'select-background',
	    'type'		 => 'multiselect',
	    'desc'		 => __( 'Select which cliparts categories to be used as background images', 'pcd' ),
	    'options'	 => $display_background,
	);

	$end		 = array( 'type' => 'sectionend' );
	$settings	 = array(
	    $begin,
	    $select_background,
	    $end,
	);
	echo o_admin_fields( $settings );
	?>
	<input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce( 'securite-nonce' ); ?>"/>
	<?php
    }

    /**
     * Get cliparts page.
     */
    public function get_cliparts_page() {
	wp_enqueue_media();
	?>
	<div class='block-form'>
	    <?php
	    $begin = array(
		'type'	 => 'sectionbegin',
		'id'	 => 'cliparts-container',
	    );

	    $price	 = array(
		'title'	 => __( 'Price', 'pcd' ),
		'name'	 => 'price',
		'type'	 => 'number',
	    );
	    $name	 = array(
		'title'	 => __( 'Name', 'pcd' ),
		'name'	 => 'name',
		'type'	 => 'text',
	    );

	    $c_image = array(
		'title'	 => __( 'Icon', 'pcd' ),
		'name'	 => 'id',
		'type'	 => 'image',
		'set'	 => 'Set',
		'remove' => 'Remove',
		'desc'	 => __( 'Component icon', 'pcd' ),
	    );

	    $cliparts = array(
		'title'			 => __( 'Components', 'pcd' ),
		'name'			 => 'pcd-cliparts-data',
		'type'			 => 'repeatable-fields',
		'fields'		 => array( $c_image, $name, $price ),
		'desc'			 => __( 'Cliparts', 'pcd' ),
		'ignore_desc_col'	 => true,
		'class'			 => 'striped',
		'add_btn_label'		 => __( 'Add clipart', 'pcd' ),
	    );

	    $end		 = array( 'type' => 'sectionend' );
	    $settings	 = apply_filters(
	    'pcd_cliparts_settings', array(
		$begin,
		$cliparts,
		$end,
	    )
	    );
	    echo o_admin_fields( $settings );
	    global $o_row_templates;
	    ?>
	</div>
	<input type="hidden" name="securite_nonce" value="<?php echo wp_create_nonce( 'securite-nonce' ); ?>"/>
	<button class="button pcd-add-cliparts"><?php esc_html_e( 'Add multiple cliparts', 'pcd' ); ?></button>
	<br><br><strong><?php esc_html_e( 'Note: ', 'pcd' ); ?></strong><?php esc_html_e( 'Please hold Ctrl or Cmd to select multiple cliparts at once from the medias popup.', 'pcd' ); ?> 
	<script>
	    var o_rows_tpl =<?php echo wp_json_encode( $o_row_templates ); ?>;
	</script>
	<?php
    }

    /**
     * Register the custom post type of pcd configurations.
     */
    public function register_cpt_config() {

	$labels = array(
	    'name'			 => _x( 'Configurations', 'pcd' ),
	    'singular_name'		 => _x( 'Configurations', 'pcd' ),
	    'add_new'		 => _x( 'New configuration', 'pcd' ),
	    'add_new_item'		 => _x( 'New configuration', 'pcd' ),
	    'edit_item'		 => _x( 'Edit configuration', 'pcd' ),
	    'new_item'		 => _x( 'New configuration', 'pcd' ),
	    'view_item'		 => _x( 'View configuration', 'pcd' ),
	    'not_found'		 => _x( 'No configuration found', 'pcd' ),
	    'not_found_in_trash'	 => _x( 'No configuration in the trash', 'pcd' ),
	    'menu_name'		 => _x( 'Product Designer', 'pcd' ),
	    'all_items'		 => _x( 'Configurations', 'pcd' ),
	);

	$args = array(
	    'labels'		 => $labels,
	    'hierarchical'		 => false,
	    'description'		 => 'Configurations',
	    'supports'		 => array( 'title' ),
	    'public'		 => false,
	    'show_ui'		 => true,
	    'show_in_menu'		 => false,
	    'show_in_nav_menus'	 => false,
	    'publicly_queryable'	 => false,
	    'exclude_from_search'	 => true,
	    'has_archive'		 => false,
	    'query_var'		 => false,
	    'can_export'		 => true,
	);

	register_post_type( 'pcd-config', $args );
    }

    /**
     * Get the order of meta box
     *
     * @param array $order The array of meta ordored.
     */
    public function get_metabox_order( $order ) {
	$order[ 'advanced' ] = 'pcd-cases-type,pcd-devices-and-cases-settings,pcd-text-settings,pcd-background-settings,pcd-metas-pricing-rules,pcd-config-templates,pcd-metas-output,submitdiv';
	return $order;
    }

    /**
     * Adds the Custom column to the default products list to help identify which ones are custom
     *
     * @param array $defaults Default columns.
     * @return array
     */
    public function get_product_columns( $defaults ) {
	$defaults[ 'is_customizable' ] = __( 'Custom', 'pcd' );
	return $defaults;
    }

    /**
     * Sets the Custom column value on the products list to help identify which ones are custom
     *
     * @param type $column_name Column name.
     * @param type $id Product ID.
     */
    public function get_products_columns_values( $column_name, $id ) {
	if ( 'is_customizable' === $column_name ) {
	    $pcd_metas = get_post_meta( $id, 'pcd-metas', true );

	    if ( isset( $pcd_metas[ $id ][ 'config-id' ] ) ) {
		if ( empty( $pcd_metas[ $id ][ 'config-id' ] ) ) {
		    esc_html_e( 'Yes', 'pcd' );
		} else {
		    esc_html_e( 'Yes', 'pcd' );
		}
	    } else {
		esc_html_e( 'No', 'pcd' );
	    }
	}
    }

}
