<?php
/**
 * Editor code.
 *
 * @link       http://orionorigin.com
 * @since      1.0
 *
 * @package    Pcd
 * @subpackage Pcd/includes
 */

/**
 * Editor class.
 *
 * This class defines all code necessary for editor
 *
 * @since      1.0
 * @package    Pcd
 * @subpackage Pcd/includes
 * @author     ORION <support@orionorigin.com>
 */
class PCD_Editor {

	/**
	 * The item id.
	 *
	 * @var type the item id.
	 */
	public $item_id;

	/**
	 * The root item id.
	 *
	 * @var type the root item id.
	 */
	public $root_item_id;

	/**
	 * The product.
	 *
	 * @var type the product.
	 */
	public $pcd_product;

	/**
	 * The constructor.
	 *
	 * @param type $item_id the item id.
	 */
	public function __construct( $item_id ) {
		if ( $item_id ) {
			$this->item_id      = $item_id;
			$this->pcd_product  = new PCD_Product( $item_id );
			$this->root_item_id = $this->pcd_product->root_product_id;
		}
	}

	/**
	 * Get editor.
	 *
	 * @global type $pcd_settings the settings.
	 * @return string output.
	 */
	public function get_editor() {
		global $pcd_settings;

		ob_start();
		$product = wc_get_product( $this->item_id );
		if ( ! $product ) {
			esc_html_e( 'Error: Invalid product: ', 'pcd' );
			echo "$this->item_id<br>";
			esc_html_e( '1- Is your customization page defined as homepage?', 'pcd' );
			echo '<br>';
			esc_html_e( '2- Is your customization page defined as one of woocommerce pages?', 'pcd' );
			echo '<br>';
			esc_html_e( '3- Does the product you are trying to customize exists and is published in your shop?', 'pcd' );
			echo '<br>';
			esc_html_e( '4- Are you accessing this page from one of the product designer buttons?', 'pcd' ) . '<br>';
			return;
		}
		if ( ! $this->pcd_product->has_model() ) {
			esc_html_e( 'Error: No model defined for this product. A customizable product should have at least one model defined.', 'pcd' );
			return;
		}
		$pcd_metas = $this->pcd_product->settings;

		pcd_init_canvas_vars( $pcd_metas, $product, $this );
		$ui_options = get_proper_value( $pcd_settings, 'pcd-ui-options', array() );
		$skin       = get_proper_value( $ui_options, 'skin', 'PCD_Skin_Default' );
                $editor     = new $skin( $this, $pcd_metas );

		$raw_output = $editor->display();
		echo $raw_output;

		$output = ob_get_contents();
		ob_end_clean();
		return $output;
	}

}
