<?php
/**
 * Pcd functions file.
 *
 * @link       orionorigin@orionorigin.com
 * @since      1.0.0
 *
 * @package    Pcd
 * @subpackage Pcd/includes
 */

/**
 * Check if is on admin screen.
 */
function is_pcd_admin_screen() {
    $screen = get_current_screen();
    if (
    isset( $screen->base ) &&
    (
    strpos( $screen->base, 'pcd' ) !== false || strpos( $screen->post_type, 'pcd' ) !== false || 'product' === $screen->post_type || 'shop_order' === $screen->post_type || 'pcd-config' === $screen->post_type
    )
    ) {
	return true;
    } else {
	return false;
    }
}

function pcd_generate_design_buttons_css() {
    global $pcd_settings;
    $ui_options = get_proper_value( $pcd_settings, 'pcd-ui-options', array() );
    pcd_generate_css_tab( $ui_options, 'pcd-customize-product', '', 'buttons', array(), true );
    pcd_generate_css_tab( $ui_options, 'btn-choose', '', 'buttons', array(), true );
}

function pcd_generate_css( $values ) {
    $first_value = current( $values );
    if ( empty( $first_value ) ) {
	return;
    }

    reset( $values );
    ?>
    <style>
    <?php
    foreach ( $values as $key => $value ) {
	echo $key;
	?>
	    {
	<?php
	foreach ( $value as $attr => $val ) {
	    echo $attr . ':' . $val . '!important;';
	}
	?>
	    }
	<?php
    }
    ?>
    </style>
    <?php
}

/**
 * Generates the css code related to each interface element
 *
 * @param array  $options Options group
 * @param string $id Selector ID
 * @param type   $icon_field Icon field
 * @param type   $keyword Item keyword in options
 */
function pcd_generate_css_tab( $options, $id, $icon_field, $keyword, $icons_properties = array(), $class = false, $other_options = array() ) {

    if ( ! empty( $other_options ) ) {
	foreach ( $other_options as $key => $other_option ) {
	    $param_color_selected = $keyword . '-background-color-hover';
	}
    } else {
	$param_color_selected = $keyword . '-background-color-hover';
    }

    $param_color		 = $keyword . '-background-color';
    $param_label_color	 = $keyword . '-text-color';
    $tab_text_color_normal	 = get_proper_value( $options, $param_color, '' );
    $tab_text_color_hover	 = get_proper_value( $options, $param_color_selected, '' );
    $label_color		 = get_proper_value( $options, $param_label_color, '' );

    $icon_id		 = get_proper_value( $options, $icon_field, '' );
    $attribut_value_array	 = array();
    if ( ! empty( $tab_text_color_normal ) ) {
	$attribut_value_array[ 'background-color' ] = $tab_text_color_normal;
	if ( $keyword == 'plus-btn' || $keyword == 'minus-btn' ) {
	    $attribut_value_array[ 'background' ]		 = $tab_text_color_normal;
	    $attribut_value_array[ 'box-shadow' ]		 = 'inset 0px 1px 0px 0px ' . $tab_text_color_normal;
	    $attribut_value_array[ '-moz-box-shadow' ]	 = 'inset 0px 1px 0px 0px ' . $tab_text_color_normal;
	    $attribut_value_array[ '-webkit-box-shadow' ]	 = 'inset 0px 1px 0px 0px ' . $tab_text_color_normal;
	}
    }

    if ( ! empty( $label_color ) ) {
	$attribut_value_array[ 'color' ] = $label_color;
    }

    if ( ! empty( $tab_text_color_hover ) ) {
	if ( $class ) {
	    $id_hover = '.' . $id . ':hover';
	} else {
	    $id_hover = '#' . $id . ':hover';
	}
	$selector_attribut[ $id_hover ][ 'background-color' ] = $tab_text_color_hover;
    }
    if ( ! empty( $icon_id ) ) {
	$icon_url					 = o_get_proper_image_url( $icon_id, 'thumbnail' );
	$icon_css					 = "url($icon_url)";
	$attribut_value_array[ 'background-image' ]	 = $icon_css;
	if ( empty( $icons_properties ) ) {
	    $attribut_value_array[ 'background-size' ]	 = '30px';
	    $attribut_value_array[ 'background-position' ]	 = '3%';
	} else {
	    $attribut_value_array = array_merge( $attribut_value_array, $icons_properties );
	}
    }

    if ( $class ) {
	$selector = '.' . $id;
    } else {
	$selector = '#' . $id;
    }
    $selector_attribut[ $selector ] = $attribut_value_array;
    pcd_generate_css( $selector_attribut );
}

function pcd_get_custom_products() {
    global $wpdb;

    $search		 = "(

pm.meta_value like '%config-id\";s:1%'
or pm.meta_value like '%config-id\";s:2%'
or pm.meta_value like '%config-id\";s:3%'
or pm.meta_value like '%config-id\";s:4%'
or pm.meta_value like '%config-id\";s:5%'
or pm.meta_value like '%config-id\";s:6%'
or pm.meta_value like '%config-id\";s:7%'
or pm.meta_value like '%config-id\";s:8%'
or pm.meta_value like '%config-id\";s:9%'
or pm.meta_value like '%config-id\";i:%'
)";
    $products	 = $wpdb->get_results(
    "
                           SELECT p.id
                           FROM $wpdb->posts p
                           JOIN $wpdb->postmeta pm on pm.post_id = p.id 
                           WHERE p.post_type = 'product'
                           AND pm.meta_key = 'pcd-metas'
                           AND $search
                           "
    );
    // set_transient($transient_key, $products, 12 * HOUR_IN_SECONDS);
    return $products;
}

/**
 * Returns user ordered designs
 *
 * @global object $wpdb
 * @param type $user_id
 * @return array
 */
function pcd_get_user_orders_designs( $user_id ) {
    global $wpdb;
    $designs = array();
    $args	 = array(
	'numberposts'	 => -1,
	'meta_key'	 => '_customer_user',
	'meta_value'	 => $user_id,
	'post_type'	 => 'shop_order',
	'post_status'	 => array( 'wc-processing', 'wc-completed', 'wc-on-hold' ),
    );

    $orders = get_posts( $args );
    foreach ( $orders as $order ) {
	$sql_1		 = 'select distinct order_item_id FROM ' . $wpdb->prefix . "woocommerce_order_items where order_id=$order->ID";
	$order_items_id	 = $wpdb->get_col( $sql_1 );
	foreach ( $order_items_id as $order_item_id ) {
	    $sql_2			 = 'select meta_key, meta_value FROM ' . $wpdb->prefix . "woocommerce_order_itemmeta where order_item_id=$order_item_id and meta_key in ('_product_id', '_variation_id', 'wpc_data')";
	    $order_item_metas	 = $wpdb->get_results( $sql_2 );
	    $normalized_item_metas	 = array();
	    foreach ( $order_item_metas as $order_item_meta ) {
		$normalized_item_metas[ $order_item_meta->meta_key ] = $order_item_meta->meta_value;
	    }
	    if ( ! isset( $normalized_item_metas[ 'wpc_data' ] ) ) {
		continue;
	    }

	    if ( $normalized_item_metas[ '_variation_id' ] ) {
		$product_id = $normalized_item_metas[ '_variation_id' ];
	    } else {
		$product_id = $normalized_item_metas[ '_product_id' ];
	    }
	    array_push( $designs, array( $product_id, $order->post_date, unserialize( $normalized_item_metas[ 'wpc_data' ] ), $order_item_id ) );
	}
    }
    return $designs;
}

/**
 * Initialize canvas variables.
 *
 * @global type $pcd_settings the settings.
 * @global type $wp_query the WordPress query.
 * @global type $wpdb the data base instance.
 * @param type $pcd_metas the meta.
 * @param type $product the product.
 * @param type $editor the editor.
 */
function pcd_init_canvas_vars( $pcd_metas, $product, $editor ) {
    global $pcd_settings, $wp_query, $wpdb;
    $pcd_query_vars		 = array();
    $general_options	 = $pcd_settings[ 'pcd-general-options' ];
    $text_options		 = $pcd_settings[ 'pcd-texts-options' ];
    $colors_options		 = $pcd_settings[ 'pcd-colors-options' ];
    $pcd_output_options	 = $pcd_settings[ 'pcd-output-options' ];

    $use_retina_mode = 'yes';

    $canvas_w	 = $editor->pcd_product->get_option( $pcd_metas, $general_options, 'canvas-w', 800 );
    $canvas_h	 = $editor->pcd_product->get_option( $pcd_metas, $general_options, 'canvas-h', 500 );
    $origin_x	 = get_proper_value( $text_options, 'origin-x', 'left' );
    $watermark	 = get_proper_value( $pcd_metas, 'watermark', '' );

    $output_settings	 = get_proper_value( $pcd_metas, 'output-settings', array() );
    //$output_w          = $editor->pcd_product->get_output_image_width();
    $output_loop_delay	 = $editor->pcd_product->get_option( $output_settings, $pcd_output_options, 'pcd-output-loop-delay', 1000 );
    $output_format		 = get_proper_value( $pcd_metas[ 'output-settings' ], 'output-format' );
    $generate_svg		 = false;
    if ( $output_format == 'svg' ) {
	$generate_svg	 = 'svg';
	$output_format	 = 'png';
    }
    $svg_colorization	 = get_proper_value( $colors_options, 'pcd-svg-colorization', 'by-path' );
    $pcd_palette_type	 = get_proper_value( $colors_options, 'pcd-color-palette', 'unlimited' );
    $palette		 = get_proper_value( $colors_options, 'pcd-custom-palette', '' );
    $palette_tpl		 = '';

    $disable_shortcut = get_proper_value( $general_options, 'disable-keyboard-shortcuts', 0 );

    if ( ! empty( $palette ) && is_array( $palette ) ) {
	$palette_tpl = apply_filters( 'pcd_custom_palette_tpl', $palette_tpl, $palette );
	// Check if the custom template is not already set. Avoid useless loop.
	if ( empty( $palette_tpl ) ) {
	    foreach ( $palette as $color ) {
		$hex		 = str_replace( '#', '', $color );
		$palette_tpl	 .= '<span style="background-color: ' . $color . '" data-color="' . $hex . '" class="pcd-custom-color"></span>';
	    }
	}
    }

    $available_variations = array();
    if ( 'variable' === $product->get_type() ) {
	$available_variations = $product->get_available_variations();
    }

    $price_format = pcd_get_price_format();
    if ( isset( $wp_query->query_vars[ 'tpl' ] ) ) {
	$tpl_id			 = $wp_query->query_vars[ 'tpl' ];
	$pcd_query_vars[ 'tpl' ] = $tpl_id;
	$data			 = get_post_meta( $tpl_id, 'data', true );
	// Fix serialisation issue after moving the data
	if ( $data === false ) {
	    $data = pcd_fix_template_data( $tpl_id );
	}
    } elseif ( is_admin() && get_post_type() == 'pcd-template' ) {
	$tpl_id	 = get_the_ID();
	$data	 = get_post_meta( $tpl_id, 'data', true );
	// Fix serialisation issue after moving the data
	if ( $data === false ) {
	    $data = pcd_fix_template_data( $tpl_id );
	}
    } elseif ( isset( $wp_query->query_vars[ 'edit' ] ) ) {
	//$variation_id = $wp_query->query_vars['product_id'];
	$cart_item_key			 = $wp_query->query_vars[ 'edit' ];
	$pcd_query_vars[ 'edit' ]	 = $cart_item_key;
	global $woocommerce;
	$cart				 = $woocommerce->cart->get_cart();
	$data				 = $cart[ $cart_item_key ][ 'pcd_generated_data' ];
	// Useful when editing cart item
	if ( $data ) {
	    $data = stripslashes_deep( $data );
	}
    } elseif ( isset( $wp_query->query_vars[ 'design_index' ] ) ) {
	global $current_user;
	$design_index				 = $wp_query->query_vars[ 'design_index' ];
	$pcd_query_vars[ 'design_index' ]	 = $design_index;
	$user_designs				 = get_user_meta( $current_user->ID, 'pcd_saved_designs' );
	if ( isset( $user_designs[ $design_index ][ 3 ] ) && ! empty( $user_designs[ $design_index ][ 3 ] ) ) {
	    $data = $user_designs[ $design_index ][ 3 ];
	}
    } elseif ( isset( $wp_query->query_vars[ 'oid' ] ) ) {
	$order_item_id		 = $wp_query->query_vars[ 'oid' ];
	$pcd_query_vars[ 'oid' ] = $order_item_id;
	$sql			 = 'select meta_value FROM ' . $wpdb->prefix . "woocommerce_order_itemmeta where order_item_id=$order_item_id and meta_key='pcd_data'";
	// echo $sql;
	$pcd_data		 = $wpdb->get_var( $sql );
	$data			 = unserialize( $pcd_data );
    }
    $editor_params = apply_filters(
    'pcd_editor_params', array(
	'canvas_w'		 => $canvas_w,
	'canvas_h'		 => $canvas_h,
	'originX'		 => $origin_x,
	'watermark'		 => $watermark,
	//'output_w'            => $output_w,
	'output_loop_delay'	 => $output_loop_delay,
	'output_format'		 => $output_format,
	'generate_svg'		 => $generate_svg,
	'svg_colorization'	 => $svg_colorization,
	'palette_type'		 => $pcd_palette_type,
	'global_variation_id'	 => $editor->item_id,
	'disable_shortcuts'	 => $disable_shortcut,
	'palette_tpl'		 => $palette_tpl,
	'translated_strings'	 => array(
	    'deletion_error_msg'		 => __( 'The deletion of this object is not allowed', 'pcd' ),
	    'loading_msg'			 => __( 'Just a moment', 'pcd' ),
	    'empty_object_msg'		 => __( 'The edition area is empty.', 'pcd' ),
	    'delete_all_msg'		 => __( 'Do you really want to delete all items in the design area ?', 'pcd' ),
	    'delete_msg'			 => __( 'Do you really want to delete the selected items ?', 'pcd' ),
	    'empty_txt_area_msg'		 => __( 'Please enter the text to add.', 'pcd' ),
	    'cart_item_edition_switch'	 => __( "You're editing a cart item. If you switch to another product and update the cart, the previous item will be removed from the cart. Do you really want to continue?", 'pcd' ),
	    'svg_background_tooltip'	 => __( 'Background color (SVG files only)', 'pcd' ),
	    'cliparts_search_no_result'	 => __( 'There are no results that match your search.', 'pcd' ),
	),
	'query_vars'		 => $pcd_query_vars,
	'thousand_sep'		 => wc_get_price_thousand_separator(),
	'decimal_sep'		 => wc_get_price_decimal_separator(),
	'nb_decimals'		 => wc_get_price_decimals(),
	'currency'		 => get_woocommerce_currency_symbol(),
	'price_format'		 => $price_format,
	'variations'		 => $available_variations,
	'lazy_placeholder'	 => PCD_URL . '/public/images/rolling.gif',
	'enable_retina'		 => $use_retina_mode,
	'content_url'		 => get_site_url() . '/'
    ), $pcd_metas, $product, $editor
    );



    if ( isset( $data ) && ! empty( $data ) ) {
	?>
	<script>
	    var to_load =<?php echo json_encode( $data ); ?>;
	</script>
	<?php
    }
    ?>


    <script>
        var pcd =<?php echo wp_json_encode( $editor_params ); ?>;
        var pcd_upload_image_path = "<?php echo plugin_dir_url( __FILE__ ) . 'skins/default/assets/images/upload-image.svg'; ?>";
        var pcd =<?php echo wp_json_encode( $editor_params ); ?>;
        var pcd_metas_json =<?php echo wp_json_encode( $pcd_metas ); ?>;
        var pcd_layouts =<?php echo wp_json_encode( pcd_get_selected_layouts( $pcd_metas ) ); ?>;
        var pcd_models =<?= pcd_get_models_info(); ?>;
        var pcd_icon_model = "<?php echo plugin_dir_url( __FILE__ ) . 'skins/default/assets/images/iconModel/'; ?>";
        var pcd_background_model = "<?php echo plugin_dir_url( __FILE__ ) . 'skins/default/assets/images/backgroundModel/'; ?>";
        var pcd_overlay_model = "<?php echo plugin_dir_url( __FILE__ ) . 'skins/default/assets/images/overlayModel/'; ?>";
    </script>
    <?php
}

/**
 * Get template price.
 * 
 * @param type $tpl_id The template id.
 * @return int The base price.
 */
function pcd_get_template_price( $tpl_id ) {
    if ( empty( $tpl_id ) ) {
	return 0;
    }

    $tpl_base_price = get_post_meta( $tpl_id, 'base-price', true );
    if ( empty( $tpl_base_price ) ) {
	$tpl_base_price = 0;
    }

    return $tpl_base_price;
}

function pcd_get_variation_from_attributes( $root_item_id ) {
    $available_variations = pcd_get_available_variations( $root_item_id );
    foreach ( $available_variations as $key => $value ) {
	$load_product = new PCD_Product( $key );
	if ( ! $load_product->is_customizable() ) {
	    unset( $available_variations[ $key ] );
	}
    }
    return array_keys( $available_variations );
}

function pcd_get_available_variations( $root_item_id ) {
    $root_product			 = wc_get_product( $root_item_id );
    $default_available_variations	 = $root_product->get_available_variations();
    $variations			 = array();
    foreach ( $default_available_variations as $variation_data ) {
	$variations[ $variation_data[ 'variation_id' ] ] = $variation_data[ 'attributes' ];
    }
    return $variations;
}

function pcd_make_variation_combine( $attribute, $variation_values, $combine_tab ) {
    $new_combine_tab = [];
    foreach ( $combine_tab as $variation ) {
	if ( isset( $variation[ $attribute ] ) ) {
	    foreach ( $variation_values as $values ) {
		$variation[ $attribute ] = $values;
		$new_combine_tab[]	 = $variation;
	    }
	}
    }
    return $new_combine_tab;
}

function pcd_woocommerce_version_check( $version = '2.5' ) {
    if ( class_exists( 'WooCommerce' ) ) {
	global $woocommerce;
	if ( version_compare( $woocommerce->version, $version, '>=' ) ) {
	    return true;
	}
    }
    return false;
}

function pcd_get_models_info() {
    $models = [
	'iphoneX'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'x',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'X_XS.png',
		    'image'		 => 'X_XS.png',
		    'overlay'	 => 'X_XS.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'iphoneXMax'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'XMax',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'XMax.png',
		    'image'		 => 'XMax.png',
		    'overlay'	 => 'XMax.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphoneXS'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'xs',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'X_XS.png',
		    'image'		 => 'X_XS.png',
		    'overlay'	 => 'X_XS.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphoneXSmax'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'xs max',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'XS_max.png',
		    'image'		 => 'XS_max.png',
		    'overlay'	 => 'XS_max.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphoneXR'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'xs',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'XR.png',
		    'image'		 => 'XR.png',
		    'overlay'	 => 'XR.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphoneXR-V1'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'XR-V1',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'XR-V1.png',
		    'image'		 => 'XR-V1.png',
		    'overlay'	 => 'XR-V1.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphoneXR-V2'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => 'XR-V2',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'XR-V2.png',
		    'image'		 => 'XR-V2.png',
		    'overlay'	 => 'XR-V2.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone11'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '11',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '11.png',
		    'image'		 => '11.png',
		    'overlay'	 => '11.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone11pro'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '11_pro',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '11_pro.png',
		    'image'		 => '11_pro.png',
		    'overlay'	 => '11_pro.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone11promax'	 => [
	    'brand'	 => 'iphone',
	    'name'	 => '11_pro_max',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '11_pro_max.png',
		    'image'		 => '11_pro_max.png',
		    'overlay'	 => '11_pro_max.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone6plus'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '6_plus',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '6_plus_6s_plus.png',
		    'image'		 => '6_plus_6s_plus.png',
		    'overlay'	 => '6_plus_6s_plus.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone6splus'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '6s_plus',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '6_plus_6s_plus.png',
		    'image'		 => '6_plus_6s_plus.png',
		    'overlay'	 => '6_plus_6s_plus.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone7plus'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '7_plus',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '7_plus_8_plus.png',
		    'image'		 => '7_plus_8_plus.png',
		    'overlay'	 => '7_plus_8_plus.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone8plus'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '8_plus',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '7_plus_8_plus.png',
		    'image'		 => '7_plus_8_plus.png',
		    'overlay'	 => '7_plus_8_plus.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'iphone6'		 => [
	    'brand'	 => 'iphone',
	    'name'	 => '6',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '6.png',
		    'image'		 => '6.png',
		    'overlay'	 => '6.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs7'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S7',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's7.png',
		    'image'		 => 's7.png',
		    'overlay'	 => 's7.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs7edge'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S7 Edge',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's7_edge.png',
		    'image'		 => 's7_edge.png',
		    'overlay'	 => 's7_edge.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs8'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S8',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's8.png',
		    'image'		 => 's8.png',
		    'overlay'	 => 's8.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs8+'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S8+',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's8+.png',
		    'image'		 => 's8+.png',
		    'overlay'	 => 's8+.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs9'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S9',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-S9.png',
		    'image'		 => 'Galaxy-S9.png',
		    'overlay'	 => 'Galaxy-S9.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs9+'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S9+',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-S9plus.png',
		    'image'		 => 'Galaxy-S9plus.png',
		    'overlay'	 => 'Galaxy-S9plus.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs10'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S10',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's10.png',
		    'image'		 => 's10.png',
		    'overlay'	 => 's10.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs10e'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S10e',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's10e.png',
		    'image'		 => 's10e.png',
		    'overlay'	 => 's10e.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'samsungs10+'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S10+',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's10+.png',
		    'image'		 => 's10+.png',
		    'overlay'	 => 's10+.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A5'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A5',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A5.png',
		    'image'		 => 'Galaxy-A5.png',
		    'overlay'	 => 'Galaxy-A5.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A6-V1'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A6-V1',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A6-V1.png',
		    'image'		 => 'Galaxy-A6-V1.png',
		    'overlay'	 => 'Galaxy-A6-V1.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A6-V2'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A6-V2',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A6-V2.png',
		    'image'		 => 'Galaxy-A6-V2.png',
		    'overlay'	 => 'Galaxy-A6-V2.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A7'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A7',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A7.png',
		    'image'		 => 'Galaxy-A7.png',
		    'overlay'	 => 'Galaxy-A7.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A8'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A8',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A8.png',
		    'image'		 => 'Galaxy-A8.png',
		    'overlay'	 => 'Galaxy-A8.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-A9'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-A9',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-A9.png',
		    'image'		 => 'Galaxy-A9.png',
		    'overlay'	 => 'Galaxy-A9.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-J2-Pro'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-J2-Pro',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-J2-Pro.png',
		    'image'		 => 'Galaxy-J2-Pro.png',
		    'overlay'	 => 'Galaxy-J2-Pro.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-J4'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-J4',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-J4.png',
		    'image'		 => 'Galaxy-J4.png',
		    'overlay'	 => 'Galaxy-J4.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-J6'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-J6',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-J6.png',
		    'image'		 => 'Galaxy-J6.png',
		    'overlay'	 => 'Galaxy-J6.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-J7'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-J7',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-J7.png',
		    'image'		 => 'Galaxy-J7.png',
		    'overlay'	 => 'Galaxy-J7.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-J8'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-J8',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-J8.png',
		    'image'		 => 'Galaxy-J8.png',
		    'overlay'	 => 'Galaxy-J8.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'Galaxy-Note-9'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'Galaxy-Note-9',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Galaxy-Note-9.png',
		    'image'		 => 'Galaxy-Note-9.png',
		    'overlay'	 => 'Galaxy-Note-9.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'samsungs10+'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S10+',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's10+.png',
		    'image'		 => 's10+.png',
		    'overlay'	 => 's10+.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	], 'samsungs10+'		 => [
	    'brand'	 => 'samsung',
	    'name'	 => 'S10+',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 's10+.png',
		    'image'		 => 's10+.png',
		    'overlay'	 => 's10+.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'Honnor-10-V1'		 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'Honnor-10-V1',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Honnor-10-V1.png',
		    'image'		 => 'Honnor-10-V1.png',
		    'overlay'	 => 'Honnor-10-V1.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'Honnor-10-V2'		 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'Honnor-10-V2',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Honnor-10-V2.png',
		    'image'		 => 'Honnor-10-V2.png',
		    'overlay'	 => 'Honnor-10-V2.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'P20'			 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'P20',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'P20.png',
		    'image'		 => 'P20.png',
		    'overlay'	 => 'P20.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'P20-Lite'		 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'P20-Lite',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'P20-Lite.png',
		    'image'		 => 'P20-Lite.png',
		    'overlay'	 => 'P20-Lite.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'P20-Pro'		 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'P20-Pro',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'P20-Pro.png',
		    'image'		 => 'P20-Pro.png',
		    'overlay'	 => 'P20-Pro.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'Y5'			 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'Y5',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Y5.png',
		    'image'		 => 'Y5.png',
		    'overlay'	 => 'Y5.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'Y6'			 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'Y6',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Y6.png',
		    'image'		 => 'Y6.png',
		    'overlay'	 => 'Y6.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'Y9'			 => [
	    'brand'	 => 'huawei',
	    'name'	 => 'Y9',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Y9.png',
		    'image'		 => 'Y9.png',
		    'overlay'	 => 'Y9.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'G7'			 => [
	    'brand'	 => 'LG',
	    'name'	 => 'G7',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'G7.png',
		    'image'		 => 'G7.png',
		    'overlay'	 => 'G7.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'K8'			 => [
	    'brand'	 => 'LG',
	    'name'	 => 'K8',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'K8.png',
		    'image'		 => 'K8.png',
		    'overlay'	 => 'K8.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'E5-Play'		 => [
	    'brand'	 => 'motorola',
	    'name'	 => 'E5-Play',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'E5-Play.png',
		    'image'		 => 'E5-Play.png',
		    'overlay'	 => 'E5-Play.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'nokia-6'		 => [
	    'brand'	 => 'nokia',
	    'name'	 => 'nokia-6',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '6.png',
		    'image'		 => '6.png',
		    'overlay'	 => '6.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'oneplus-6'		 => [
	    'brand'	 => 'oneplus',
	    'name'	 => 'oneplus-6',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '6.png',
		    'image'		 => '6.png',
		    'overlay'	 => '6.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'oppo-R15'		 => [
	    'brand'	 => 'oppo',
	    'name'	 => 'oppo-R15',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'R15.png',
		    'image'		 => 'R15.png',
		    'overlay'	 => 'R15.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'pixel-3Xl'		 => [
	    'brand'	 => 'pixel',
	    'name'	 => 'pixel-3Xl',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => '3Xl.png',
		    'image'		 => '3Xl.png',
		    'overlay'	 => '3Xl.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	]
	,
	'Xperia-XZ2'		 => [
	    'brand'	 => 'sony',
	    'name'	 => 'Xperia-XZ2',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Xperia-XZ2.png',
		    'image'		 => 'Xperia-XZ2.png',
		    'overlay'	 => 'Xperia-XZ2.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	]
	,
	'Xperia-XZ2-COmpact'	 => [
	    'brand'	 => 'sony',
	    'name'	 => 'Xperia-XZ2-COmpact',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Xperia-XZ2-COmpact.png',
		    'image'		 => 'Xperia-XZ2-COmpact.png',
		    'overlay'	 => 'Xperia-XZ2-COmpact.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	],
	'vivo-Nex'		 => [
	    'brand'	 => 'vivo',
	    'name'	 => 'vivo-Nex',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Nex.png',
		    'image'		 => 'Nex.png',
		    'overlay'	 => 'Nex.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	]
	,
	'Redmi-Note-5'		 => [
	    'brand'	 => 'xiaomi',
	    'name'	 => 'Redmi-Note-5',
	    'cases'	 => [
		0 =>
		[
		    'name'		 => 'default',
		    'desc'		 => 'Default case',
		    'icon'		 => 'Redmi-Note-5.png',
		    'image'		 => 'Redmi-Note-5.png',
		    'overlay'	 => 'Redmi-Note-5.png',
		    'price'		 => '500',
		    'width'		 => '240.16393442295',
		    'height'	 => '500',
		]
	    ]
	]
    ];
    return wp_json_encode( $models );
}

function pcd_get_available_models() {
    global $pcd_models;
    $pcd_models = [
	'iphone6plus'		 => __( 'Iphone 6 plus', 'pcd' ),
	'iphone6'		 => __( 'Iphone 6', 'pcd' ),
	'iphone6splus'		 => __( 'Iphone 6s plus', 'pcd' ),
	'iphone7plus'		 => __( 'Iphone 7 plus', 'pcd' ),
	'iphone8plus'		 => __( 'Iphone 8 plus', 'pcd' ),
	'iphoneXR'		 => __( 'Iphone XR', 'pcd' ),
	'iphoneXR-V1'		 => __( 'Iphone XR-V1', 'pcd' ),
	'iphoneXR-V2'		 => __( 'Iphone XR-V2', 'pcd' ),
	'iphoneX'		 => __( 'Iphone X', 'pcd' ),
	'iphoneXMax'		 => __( 'Iphone XMax', 'pcd' ),
	'iphoneXS'		 => __( 'Iphone XS', 'pcd' ),
	'iphoneXSmax'		 => __( 'Iphone XS Max', 'pcd' ),
	'iphone11'		 => __( 'Iphone 11', 'pcd' ),
	'iphone11pro'		 => __( 'Iphone 11 Pro', 'pcd' ),
	'iphone11promax'	 => __( 'Iphone 11 Pro Max', 'pcd' ),
	'samsungs7'		 => __( 'Samsung S7', 'pcd' ),
	'samsungs7edge'		 => __( 'Samsung S7 Edge', 'pcd' ),
	'samsungs8'		 => __( 'Samsung S8', 'pcd' ),
	'samsungs8+'		 => __( 'Samsung S8+', 'pcd' ),
	'samsungs9'		 => __( 'Samsung S9', 'pcd' ),
	'samsungs9+'		 => __( 'Samsung S9+', 'pcd' ),
	'samsungs10'		 => __( 'Samsung S10', 'pcd' ),
	'samsungs10e'		 => __( 'Samsung S10e', 'pcd' ),
	'samsungs10+'		 => __( 'Samsung S10+', 'pcd' ),
	'Galaxy-A5'		 => __( 'Galaxy A5', 'pcd' ),
	'Galaxy-A6-V1'		 => __( 'Galaxy A6 V1', 'pcd' ),
	'Galaxy-A6-V2'		 => __( 'Galaxy A6 V2', 'pcd' ),
	'Galaxy-A7'		 => __( 'Galaxy A7', 'pcd' ),
	'Galaxy-A8'		 => __( 'Galaxy A8', 'pcd' ),
	'Galaxy-A9'		 => __( 'Galaxy A9', 'pcd' ),
	'Galaxy-J2-Pro'		 => __( 'Galaxy J2 Pro', 'pcd' ),
	'Galaxy-J4'		 => __( 'Galaxy J4', 'pcd' ),
	'Galaxy-J6'		 => __( 'Galaxy J6', 'pcd' ),
	'Galaxy-J7'		 => __( 'Galaxy J7', 'pcd' ),
	'Galaxy-J8'		 => __( 'Galaxy J8', 'pcd' ),
	'Galaxy-Note-9'		 => __( 'Galaxy Note 9', 'pcd' ),
	'Honnor-10-V1'		 => __( 'Huawei Honnor 10 V1', 'pcd' ),
	'Honnor-10-V2'		 => __( 'Huawei Honnor 10 V2', 'pcd' ),
	'P20'			 => __( 'Huawei P20', 'pcd' ),
	'P20-Lite'		 => __( 'Huawei P20-Lite', 'pcd' ),
	'P20-Pro'		 => __( 'Huawei P20-Pro', 'pcd' ),
	'Y5'			 => __( 'Huawei Y5', 'pcd' ),
	'Y6'			 => __( 'Huawei Y6', 'pcd' ),
	'Y9'			 => __( 'Huawei Y9', 'pcd' ),
	'G7'			 => __( 'LG G7', 'pcd' ),
	'K8'			 => __( 'LG K8', 'pcd' ),
	'E5-Play'		 => __( 'Motorola E5-Play', 'pcd' ),
	'nokia-6'		 => __( 'Nokia 6', 'pcd' ),
	'oneplus-6'		 => __( 'Oneplus 6', 'pcd' ),
	'oppo-R15'		 => __( 'Oppo R15', 'pcd' ),
	'pixel-3Xl'		 => __( 'Pixel 3Xl', 'pcd' ),
	'Xperia-XZ2'		 => __( 'Xperia XZ2', 'pcd' ),
	'Xperia-XZ2-COmpact'	 => __( 'Xperia XZ2 COmpact', 'pcd' ),
	'vivo-Nex'		 => __( 'Vivo Nex', 'pcd' ),
	'Redmi-Note-5'		 => __( 'Redmi Note 5', 'pcd' ),
    ];
}

function pcd_get_available_layouts() {
    global $pcd_layouts;
    $layouts		 = array();
    $layouts[ 'all' ]	 = __( 'All', 'pcd' );
    $layouts[ 'layout_1' ]	 = __( 'Layout 1', 'pcd' );
    $layouts[ 'layout_2' ]	 = __( 'Layout 2', 'pcd' );
    $layouts[ 'layout_3' ]	 = __( 'Layout 3', 'pcd' );
    $layouts[ 'layout_4' ]	 = __( 'Layout 4', 'pcd' );
    $layouts[ 'layout_5' ]	 = __( 'Layout 5', 'pcd' );
    $layouts[ 'layout_6' ]	 = __( 'Layout 6', 'pcd' );
    $layouts[ 'layout_7' ]	 = __( 'Layout 7', 'pcd' );
    $layouts[ 'layout_8' ]	 = __( 'Layout 8', 'pcd' );
    $layouts[ 'layout_9' ]	 = __( 'Layout 9', 'pcd' );
    $layouts[ 'layout_10' ]	 = __( 'Layout 10', 'pcd' );
    $layouts[ 'layout_11' ]	 = __( 'Layout 11', 'pcd' );
    $layouts[ 'layout_12' ]	 = __( 'Layout 12', 'pcd' );
    $layouts[ 'layout_13' ]	 = __( 'Layout 13', 'pcd' );
    $layouts[ 'layout_14' ]	 = __( 'Layout 14', 'pcd' );
    $layouts[ 'layout_15' ]	 = __( 'Layout 15', 'pcd' );

    $pcd_layouts = $layouts;
}

function pcd_get_layouts_info() {
    $layouts = [
	'layout_1'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_1',
		'name'	 => __( 'Layout 1', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid1.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => 1
		    ],
		],
	    ]
	],
	'layout_2'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_2',
		'name'	 => __( 'Layout 2', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid2.svg',
		'nb_raw' => 2,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => 0.50
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.50,
			'width'		 => 1,
			'height'	 => 0.50
		    ],
		]
	    ]
	],
	'layout_3'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_3',
		'name'	 => __( 'Layout 3', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid3.svg',
		'nb_raw' => 3,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => 0.40
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.40,
			'width'		 => 1,
			'height'	 => 0.20
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.60,
			'width'		 => 1,
			'height'	 => 0.40
		    ],
		]
	    ]
	],
	'layout_4'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_4',
		'name'	 => __( 'Layout 4', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid4.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.10,
			'top'		 => (100 / 300),
			'width'		 => 0.80,
			'height'	 => (100 / 300)
		    ],
		],
	    ]
	],
	'layout_5'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_5',
		'name'	 => __( 'Layout 5', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid5.svg',
		'nb_raw' => 2,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 0.50,
			'height'	 => 0.50
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0,
			'width'		 => 0.50,
			'height'	 => 0.50
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.50,
			'width'		 => 0.50,
			'height'	 => 0.50
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.50,
			'width'		 => 0.50,
			'height'	 => 0.50
		    ]
		]
	    ]
	],
	'layout_6'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_6',
		'name'	 => __( 'Layout 6', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid6.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'cercle',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.20,
			'top'		 => (100 / 300),
			'radius'	 => 0.30
		    ],
		],
	    ]
	],
	'layout_7'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_7',
		'name'	 => __( 'Layout 7', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid7.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 9,
			'points'	 => [
			    [
				'x'	 => 0.50,
				'y'	 => (100 / 300)
			    ],
			    [
				'x'	 => (0.10 + 2 * (40 / 300)),
				'y'	 => (1 / 3 + 1 / 9)
			    ],
			    [
				'x'	 => 0.10,
				'y'	 => (1 / 3 + 1 / 9)
			    ],
			    [
				'x'	 => (0.10 + 2 * (40 / 300)),
				'y'	 => (1 / 3 + 2 / 9)
			    ],
			    [
				'x'	 => 0.10,
				'y'	 => (2 / 3)
			    ],
			    [
				'x'	 => 0.50,
				'y'	 => (1 / 3 + 2 / 9 + 1 / 18)
			    ],
			    [
				'x'	 => 0.90,
				'y'	 => (2 / 3)
			    ],
			    [
				'x'	 => (0.10 + 4 * (40 / 300)),
				'y'	 => (1 / 3 + 2 / 9)
			    ],
			    [
				'x'	 => 0.90,
				'y'	 => (1 / 3 + 1 / 9)
			    ],
			    [
				'x'	 => (0.10 + 4 * (40 / 300)),
				'y'	 => (1 / 3 + 1 / 9)
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.10,
			'top'		 => 1 / 3,
			'width'		 => 0.80,
			'height'	 => 1 / 3
		    ],
		],
	    ]
	],
	'layout_8'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_8',
		'name'	 => __( 'Layout 8', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid8.svg',
		'nb_raw' => 5,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ],
		    [
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.20,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.20,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.40,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.40,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.60,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.60,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.80,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.80,
			'width'		 => 0.50,
			'height'	 => 0.20
		    ]
		],
	    ]
	],
	'layout_9'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_9',
		'name'	 => __( 'Layout 9', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid9.svg',
		'nb_raw' => 5,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 0.75,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.75,
			'top'		 => 0,
			'width'		 => 0.25,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.20,
			'width'		 => 0.25,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.25,
			'top'		 => 0.20,
			'width'		 => 0.75,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.40,
			'width'		 => 0.75,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.75,
			'top'		 => 0.40,
			'width'		 => 0.25,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.60,
			'width'		 => 0.25,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.25,
			'top'		 => 0.60,
			'width'		 => 0.75,
			'height'	 => 0.20
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.80,
			'width'		 => 0.75,
			'height'	 => 0.20
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.75,
			'top'		 => 0.80,
			'width'		 => 0.25,
			'height'	 => 0.20
		    ]
		],
	    ]
	],
	'layout_10'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_10',
		'name'	 => __( 'Layout 10', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid10.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 3,
			'points'	 => [
			    [
				'x'	 => 0.50,
				'y'	 => (100 / 300)
			    ],
			    [
				'x'	 => 0.10,
				'y'	 => 2 * (100 / 300)
			    ],
			    [
				'x'	 => 0.90,
				'y'	 => 2 * (100 / 300)
			    ]
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.10,
			'top'		 => (100 / 300),
			'width'		 => 0.80,
			'height'	 => (100 / 300)
		    ],
		],
	    ]
	],
	'layout_11'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_11',
		'name'	 => __( 'Layout 11', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid11.svg',
		'nb_raw' => 1,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 4,
			'points'	 => [
			    [
				'x'	 => 0.50,
				'y'	 => 0.20
			    ],
			    [
				'x'	 => 0.20,
				'y'	 => 0.50
			    ],
			    [
				'x'	 => 0.50,
				'y'	 => 0.800
			    ],
			    [
				'x'	 => 0.80,
				'y'	 => 0.50
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.20,
			'top'		 => 0.20,
			'width'		 => 0.60,
			'height'	 => 0.60
		    ],
		],
	    ]
	],
	'layout_12'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_12',
		'name'	 => __( 'Layout 12', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid12.svg',
		'nb_raw' => 4,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => (100 / 300)
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => (100 / 600) + (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => (100 / 600) + (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 2 * (100 / 300),
			'width'		 => 1,
			'height'	 => (100 / 300)
		    ],
		],
	    ]
	],
	'layout_13'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_13',
		'name'	 => __( 'Layout 13', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid13.svg',
		'nb_raw' => 4,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => (100 / 300)
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => (100 / 300),
			'width'		 => 1,
			'height'	 => (100 / 600)
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => (100 / 600) + (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => (100 / 600) + (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 600)
		    ]
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 2 * (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 300)
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 2 * (100 / 300),
			'width'		 => 0.50,
			'height'	 => (100 / 300)
		    ]
		],
	    ]
	],
	'layout_14'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_14',
		'name'	 => __( 'Layout 14', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid14.svg',
		'nb_raw' => 4,
		'nb_col' => 2
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => 0.20
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'rect',
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.20,
			'width'		 => 1,
			'height'	 => 0.20
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 3,
			'points'	 => [
			    [
				'x'	 => 0,
				'y'	 => 0.40
			    ],
			    [
				'x'	 => 0,
				'y'	 => 1
			    ],
			    [
				'x'	 => 1,
				'y'	 => 0.40
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.40,
			'width'		 => 1,
			'height'	 => 0.40
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 3,
			'points'	 => [
			    [
				'x'	 => 1,
				'y'	 => 0.40
			    ],
			    [
				'x'	 => 1,
				'y'	 => 1
			    ],
			    [
				'x'	 => 0,
				'y'	 => 1
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.40,
			'width'		 => 1,
			'height'	 => 0.40
		    ],
		],
	    ]
	],
	'layout_15'	 => [
	    'general_info'	 => [
		'id'	 => 'layout_15',
		'name'	 => __( 'Layout 15', 'pcd' ),
		'path'	 => PCD_URL . 'includes/skins/default/assets/images/iconLayout/Uniongrid15.svg',
		'nb_raw' => 2,
		'nb_col' => 1
	    ],
	    'raws'		 =>
	    [
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 5,
			'points'	 => [
			    [
				'x'	 => 0,
				'y'	 => 0
			    ],
			    [
				'x'	 => 0,
				'y'	 => 0.20
			    ],
			    [
				'x'	 => 0.50,
				'y'	 => 0.50
			    ],
			    [
				'x'	 => 1,
				'y'	 => 0.20
			    ],
			    [
				'x'	 => 1,
				'y'	 => 0
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0,
			'width'		 => 1,
			'height'	 => 0.50
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 3,
			'points'	 => [
			    [
				'x'	 => 0,
				'y'	 => 0.20
			    ],
			    [
				'x'	 => 0.50,
				'y'	 => 0.50
			    ],
			    [
				'x'	 => 0,
				'y'	 => 0.80
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.20,
			'width'		 => 0.50,
			'height'	 => 0.30
		    ],
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 3,
			'points'	 => [
			    [
				'x'	 => 1,
				'y'	 => 0.20
			    ],
			    [
				'x'	 => 0.50,
				'y'	 => 0.50
			    ],
			    [
				'x'	 => 1,
				'y'	 => 0.80
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0.50,
			'top'		 => 0.20,
			'width'		 => 0.50,
			'height'	 => 0.30
		    ],
		],
		[
		    [
			'clip_img_path'	 => '',
			'type'		 => 'poly',
			'nb_point'	 => 5,
			'points'	 => [
			    [
				'x'	 => 0.50,
				'y'	 => 0.50
			    ],
			    [
				'x'	 => 0,
				'y'	 => 0.80
			    ],
			    [
				'x'	 => 0,
				'y'	 => 1
			    ],
			    [
				'x'	 => 1,
				'y'	 => 1
			    ],
			    [
				'x'	 => 1,
				'y'	 => 0.80
			    ],
			],
			'originX'	 => 'left',
			'originY'	 => 'top',
			'left'		 => 0,
			'top'		 => 0.50,
			'width'		 => 1,
			'height'	 => 0.50
		    ],
		]
	    ]
	],
    ];
    return $layouts;
}

function pcd_get_selected_layouts( $pcd_metas ) {
    $available_layouts	 = pcd_get_layouts_info();
    $selected_layouts	 = get_proper_value( $pcd_metas, 'select-layouts', array( 0 => 'all' ) );
    $layouts		 = [];
    if ( is_array( $available_layouts ) ) {
	if ( isset( $available_layouts[ 'layout_1' ] ) ) {
	    $layouts[ 'layout_1' ] = $available_layouts[ 'layout_1' ];
	}
	foreach ( $selected_layouts as $value ) {
	    if ( 'all' !== $value ) {
		$layouts[ $value ] = $available_layouts[ $value ];
	    } else {
		$layouts = $available_layouts;
	    }
	}
    }
    return $layouts;
}

/**
 * Get price format.
 *
 * @return string
 */
function pcd_get_price_format() {
    $currency_pos	 = get_option( 'woocommerce_currency_pos' );
    $format		 = '%s%v';

    switch ( $currency_pos ) {
	case 'left':
	    $format	 = '%s%v';
	    break;
	case 'right':
	    $format	 = '%v%s';
	    break;
	case 'left_space':
	    $format	 = '%s %v';
	    break;
	case 'right_space':
	    $format	 = '%v %s';
	    break;
	default:
	    $format	 = '%s%v';
	    break;
    }
    return $format;
}

function pcd_get_default_fonts() {
    $default = array(
	array( 'Shadows Into Light', 'http://fonts.googleapis.com/css?family=Shadows+Into+Light' ),
	array( 'Droid Sans', 'http://fonts.googleapis.com/css?family=Droid+Sans:400,700' ),
	array( 'Abril Fatface', 'http://fonts.googleapis.com/css?family=Abril+Fatface' ),
	array( 'Arvo', 'http://fonts.googleapis.com/css?family=Arvo:400,700,400italic,700italic' ),
	array( 'Lato', 'http://fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic' ),
	array( 'Just Another Hand', 'http://fonts.googleapis.com/css?family=Just+Another+Hand' ),
    );

    return $default;
}

function pcd_get_ttf_font_style( $font ) {
    $font_label	 = $font[ 0 ];
    $font_ttf_files	 = $font[ 2 ];
    foreach ( $font_ttf_files as $font_file ) {
	$font_styles	 = $font_file[ 'styles' ];
	$font_file_url	 = wp_get_attachment_url( $font_file[ 'file_id' ] );
	if ( ! $font_file_url ) {
	    continue;
	}
	foreach ( $font_styles as $font_style ) {
	    if ( $font_style == '' ) {
		$font_style_css = '';
	    } elseif ( $font_style == 'I' ) {
		$font_style_css = 'font-style:italic;';
	    } elseif ( $font_style == 'B' ) {
		$font_style_css = 'font-weight:bold;';
	    }
	    ?>
	    <style>
	        @font-face {
	    	font-family: "<?php echo $font_label; ?>";
	    	src: url('<?php echo $font_file_url; ?>') format('truetype');
		    <?php echo $font_style_css; ?>
	        }
	    </style>
	    <?php
	}
    }
}

function pcd_register_fonts() {
    $fonts = get_option( 'pcd-fonts' );
    if ( empty( $fonts ) ) {
	$fonts = pcd_get_default_fonts();
    }

    foreach ( $fonts as $font ) {
	$font_label	 = $font[ 0 ];
	$font_url	 = str_replace( 'http://', '//', $font[ 1 ] );
	if ( $font_url ) {
	    $handler = sanitize_title( $font_label ) . '-css';
	    wp_register_style( $handler, $font_url, array(), false, 'all' );
	    wp_enqueue_style( $handler );
	} elseif ( ! empty( $font[ 2 ] ) && is_array( $font[ 2 ] ) ) {
	    pcd_get_ttf_font_style( $font );
	}
    }
}
