<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       orionorigin@orionorigin.com
 * @since      1.0.0
 *
 * @package    Pcd
 * @subpackage Pcd/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Pcd
 * @subpackage Pcd/public
 * @author     orionorigin <orionorigin@orionorigin.com>
 */
class Pcd_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string $plugin_name       The name of the plugin.
     * @param      string $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Pcd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Pcd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/pcd-public.css', array(), $this->version, 'all');
        wp_enqueue_style('pcd-modal-css', PCD_URL . 'includes/skins/default/assets/css/modal.min.css', array(), '', 'all');
        
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Pcd_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Pcd_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/pcd-public.js', array('jquery'), $this->version, false);
        wp_localize_script($this->plugin_name, 'ajax_object', array('ajax_url' => admin_url('admin-ajax.php')));
        wp_enqueue_script('pcd-modal-js', PCD_URL . 'includes/skins/default/assets/js/modal/modal.min.js', array(), PCD_VERSION, false);
    }

    function get_customize_btn() {
        $product_id = get_the_ID();
        $pcd_product = new PCD_Product($product_id);
        echo $pcd_product->get_buttons(true);
    }

    function get_customize_btn_loop($html, $product) {
        global $pcd_settings;
        $general_options = $pcd_settings['pcd-general-options'];
        $hide_buttons_shop_page = get_proper_value($general_options, 'pcd-hide-btn-shop-pages', 0);
        if ($hide_buttons_shop_page) {
            return;
        }
        $product_class = get_class($product);
        if ($product_class == 'WC_Product_Simple') {
            $pcd_product = new PCD_Product($product->get_id());
            $html .= $pcd_product->get_buttons();
        }
        return $html;
    }

    public function pcd_add_rewrite_rules($param) {
        global $pcd_settings;
        global $wp_rewrite;
        $options = $pcd_settings['pcd-general-options'];
        $pcd_page_id = $options['pcd_page_id'];
        if (function_exists('icl_object_id')) {
            $pcd_page_id = icl_object_id($pcd_page_id, 'page', false, ICL_LANGUAGE_CODE);
        }
        $pcd_page = get_post($pcd_page_id);
        if (is_object($pcd_page)) {
            // $slug = $pcd_page->post_name;
            $raw_slug = get_permalink($pcd_page->ID);
            $home_url = home_url('/');
            $slug = str_replace($home_url, '', $raw_slug);
            // If the slug does not have the trailing slash, we get 404 (ex postname = /%postname%)
            $sep = '';
            if (substr($slug, -1) != '/') {
                $sep = '/';
            }
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'design' . '/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&tpl=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'edit' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&edit=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );
            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'ordered-design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&oid=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );

            add_rewrite_rule(
                    // The regex to match the incoming URL
                    $slug . $sep . 'saved-design' . '/([^/]+)/([^/]+)/?$',
                    // The resulting internal URL: `index.php` because we still use WordPress
                    // `pagename` because we use this WordPress page
                    // `designer_slug` because we assign the first captured regex part to this variable
                    'index.php?pagename=' . $slug . '&product_id=$matches[1]&design_index=$matches[2]',
                    // This is a rather specific URL, so we add it to the top of the list
                    // Otherwise, the "catch-all" rules at the bottom (for pages and attachments) will "win"
                    'top'
            );

            $wp_rewrite->flush_rules(false);
        }
    }

    public function hide_cart_button() {
        global $product;
        global $pcd_settings;
        $general_options = $pcd_settings['pcd-general-options'];
        $hide_cart_button = get_proper_value($general_options, 'pcd-hide-cart-button', true);
        $custom_products = pcd_get_custom_products();
        $anonymous_function = function ( $o ) {
            return $o->id;
        };
        $custom_products_ids = array_map($anonymous_function, $custom_products);
        $pid = $product->get_id();
        if (in_array($pid, $custom_products_ids) && $hide_cart_button) {
            ?>
            <script type="text/javascript">
                var hide_cart_button = <?php echo $hide_cart_button; ?>;
                console.log(hide_cart_button);
                jQuery('[value="<?php echo $pid; ?>"]').parent().find('.add_to_cart_button').hide();
                jQuery('[value="<?php echo $pid; ?>"]').parent().find('.single_add_to_cart_button').hide();
            </script>
            <?php
        }
    }

    public function get_item_class($classes, $class, $post_id) {
        global $pcd_settings;
        $general_options = $pcd_settings['pcd-general-options'];
        $hide_cart_button = get_proper_value($general_options, 'pcd-hide-cart-button', true);

        if (in_array('product', $classes)) {
            $pcd_product = new PCD_Product($post_id);
            if ($pcd_product->is_customizable()) {
                array_push($classes, 'pcd-is-customizable');
            }
            if ($hide_cart_button) {
                array_push($classes, 'pcd-hide-cart-button');
            }
        }
        return $classes;
    }

    /**
     * Register the plugin shortcodes
     */
    public function register_shortcodes() {
        add_shortcode('pcd-editor', array($this, 'get_editor_shortcode_handler'));
    }

    /**
     * Get editor shortcode handler.
     *
     * @global type $wp_query the WordPress query.
     * @return type object.
     */
    public function get_editor_shortcode_handler() {
        global $wp_query;
        if (!isset($wp_query->query_vars['product_id'])) {
            return __("You're trying to access the customization page whitout a product to customize. This page should only be accessed using one of the customization buttons.", 'pcd');
        }
        $item_id = $wp_query->query_vars['product_id'];
        $editor_obj = new PCD_Editor($item_id);
        return $editor_obj->get_editor();
    }

    private function pcd_get_woo_version_number() {
        // If get_plugins() isn't available, require it
        if (!function_exists('get_plugins')) {
            require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }

        // Create the plugins folder and file variables
        $plugin_folder = get_plugins('/' . 'woocommerce');
        $plugin_file = 'woocommerce.php';

        // If the plugin version number is set, return it
        if (isset($plugin_folder[$plugin_file]['Version'])) {
            return $plugin_folder[$plugin_file]['Version'];
        } else {
            // Otherwise return null
            return null;
        }
    }

    /**
     * Set variable action filters.
     *
     * @global type $pcd_settings the settings.
     */
    public function set_variable_action_filters() {
        $woo_version = $this->pcd_get_woo_version_number();
        if ($woo_version < 2.1) {
            // Old WC versions
            add_filter('woocommerce_in_cart_product_title', array($this, 'get_pcd_data'), 10, 3);
        } else {
            // New WC versions
            add_filter('woocommerce_cart_item_name', array($this, 'get_pcd_data'), 10, 3);
        }
        add_filter('the_content', array($this, 'filter_content'), 99);
    }

    /**
     * Initialize the plugin sessions
     */
    function init_sessions() {
        if (!session_id()) {
            session_start();
        }
        if (!isset($_SESSION['pcd-data-to-load'])) {
            $_SESSION['pcd-data-to-load'] = '';
        }
        $_SESSION['pcd_calculated_totals'] = false;
    }

    /**
     * Get PCD data.
     * 
     * @param type $thumbnail_code The thumbnail code.
     * @param type $values The values.
     * @param type $cart_item_key The cart item key.
     */
    public function get_pcd_data($thumbnail_code, $values, $cart_item_key) {
        $variation_id = $values['variation_id'];
        if (isset($values['pcd_design_pricing_options']) && !empty($values['pcd_design_pricing_options'])) {
            $pcd_design_pricing_options_data = PCD_Design::get_design_pricing_options_data($values['pcd_design_pricing_options']);
            $thumbnail_code .= '<br>' . $pcd_design_pricing_options_data;
        }

        if (isset($values['pcd_generated_data']) && isset($values['pcd_generated_data']['output'])) {
            $thumbnail_code .= '<br>';
            $customization_list = $values['pcd_generated_data'];
            $modals = '';
            if (class_exists('Ofb')) {
                if (isset($customization_list['output']['form_fields'])) {
                    $form_fields = $customization_list['output']['form_fields'];
                    foreach ($form_fields as $key => $value) {
                        if (!is_array($value)) {
                            $thumbnail_code .= '<p>' . $key . ' : ' . $value . '</p>';
                        } else {
                            $thumbnail_code .= '<p>' . $key . ' : ';
                            foreach ($value as $data) {
                                $thumbnail_code .= $data . ' ';
                            }
                            $thumbnail_code .= ' </p>';
                        }
                    }
                }
            }
            $i = 0;
            foreach ($customization_list['output']['files'] as $customisation_key => $customization) {
                $tmp_dir = $customization_list['output']['working_dir'];
                $generation_url = PCD_ORDER_UPLOAD_URL . "/$tmp_dir/$customisation_key/";
                if (isset($customization['preview'])) {
                    $image = $generation_url . $customization['preview'];
                } else {
                    $image = $generation_url . $customization['image'];
                }
                $original_part_img_url = $customization_list[$customisation_key]['original_part_img'];
                $modal_id = $variation_id . '_' . $cart_item_key . "$customisation_key-$i";

                $thumbnail_code .= '<span><a class="button" data-part-name="' . $customisation_key . '" data-variation-id="' . $variation_id . '" data-toggle="o-modal" data-target="#' . $modal_id . '">' . ucfirst($customisation_key) . '</a></span>';
                $modals .= '<div class="omodal fade pcd-modal pcd_part" id="' . $modal_id . '" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                                    <div class="omodal-dialog">
                                      <div class="omodal-content">
                                        <div class="omodal-header">
                                          <button type="button" class="close" data-dismiss="omodal" aria-hidden="true">&times;</button>
                                          <h4 class="omodal-title">' . __('Preview', 'pcd') . '</h4>
                                        </div>
                                        <div class="omodal-body txt-center">
                                            <div style="background-image:url(' . $original_part_img_url . ')"><img src="' . $image . '"></div>
                                        </div>
                                      </div>
                                    </div>
                                  </div>';
                $i++;
            }
            array_push(pcd_retarded_actions::$code, $modals);
            add_action('wp_footer', array('pcd_retarded_actions', 'display_code'), 10, 1);

            $pcd_product = new PCD_Product($variation_id);
            $edit_item_url = $pcd_product->get_design_url(false, $cart_item_key);
            $thumbnail_code .= '<a class="button alt" href="' . $edit_item_url . '">' . __('Edit', 'pcd') . '</a>';
        } elseif (isset($values['pcd-uploaded-designs'])) {
            $thumbnail_code .= '<br>';
            foreach ($values['pcd-uploaded-designs'] as $custom_design) {
                $thumbnail_code .= '<span class="pcd-custom-design"><a class="button" href=' . $custom_design . '>' . __('Custom design', 'pcd') . '</a></span>';
            }
        }
        echo $thumbnail_code;
    }
    /**
     * Filter content.
     *
     * @global type $pcd_settings the settings.
     * @global type $wp_query the WordPress query.
     * @param type $content the content.
     * @return type
     */
    public function filter_content($content) {
        global $pcd_settings, $wp_query;

        $options = $pcd_settings['pcd-general-options'];
        $pcd_page_id = $options['pcd_page_id'];
        if (function_exists('icl_object_id')) {
            $pcd_page_id = icl_object_id($pcd_page_id, 'page', false, ICL_LANGUAGE_CODE);
        }
        $current_page_id = get_the_ID();
        if (!is_admin() && $pcd_page_id == $current_page_id && isset($wp_query->query_vars['product_id']) && !empty($wp_query->query_vars['product_id'])) {
            $item_id = $wp_query->query_vars['product_id'];
            $editor_obj = new PCD_Editor($item_id);
            $content .= $editor_obj->get_editor();
        }
        return $content;
    }

    /**
     * Add query variables.
     *
     * @param type $a_vars the array variables.
     * @return array.
     */
    public function pcd_add_query_vars($a_vars) {
        $a_vars[] = 'product_id';
        $a_vars[] = 'tpl';
        $a_vars[] = 'edit';
        $a_vars[] = 'design_index';
        $a_vars[] = 'oid';
        return $a_vars;
    }

    /**
     * Handle picture upload.
     */
    public function pcd_handle_picture_upload() {
         if (!check_ajax_referer('pcd-picture-upload-nonce', 'nonce', false) && !check_ajax_referer('pcd-bg-upload-nonce', 'nonce', false)) {
          //var_dump('hi');
          $busted = __('Cheating huh?', 'pcd');
          die(esc_html($busted));
          }
        $is_bg_upload = FALSE;
        $class = "";
	$del_class="";
        if (isset($_POST["is_bg_upload"]) && "1" == $_POST["is_bg_upload"]) {
            $is_bg_upload = TRUE;
            $generation_path = PCD_TMP_BG_PATH;
            if (!is_dir($generation_path)) {
                wp_mkdir_p($generation_path);
            }
            $generation_url = PCD_TMP_BG_URL;
            $class = "image-bg";
	    $del_class=" uploaded-bg-del";
        } else {
            $generation_path = PCD_TMP_UPLOAD_PATH;
            if (!is_dir($generation_path)) {
                wp_mkdir_p($generation_path);
            }
            $generation_url = PCD_TMP_UPLOAD_URL;
            $class = "image-uploaded";
        }

        $file_name = uniqid();
        $options = get_option('pcd-upload-options');
        $valid_formats = $options['pcd-upl-extensions'];
        if (!$valid_formats) {
            $valid_formats = array('jpg', 'jpeg', 'png', 'gif', 'bmp', 'svg');
        }
        $name = $_FILES['userfile']['name'];
        $size = $_FILES['userfile']['size'];
        if (isset($_POST) and $_SERVER['REQUEST_METHOD'] == 'POST') {
            if (strlen($name)) {
                $success = 0;
                $message = '';
                $img_url = '';
                $img_id = uniqid();
                $path_parts = pathinfo($name);
                $ext = strtolower($path_parts['extension']);
                if (in_array($ext, $valid_formats)) {
                    $tmp = $_FILES['userfile']['tmp_name'];
                    if (move_uploaded_file($tmp, $generation_path . '/' . $file_name . ".$ext")) {
                        $min_width = $options['pcd-min-upload-width'];
                        $min_height = $options['pcd-min-upload-height'];
                        $valid_formats_for_thumb = array('psd', 'eps', 'pdf');
                        if ($min_width > 0 || $min_height > 0) {
                            list($width, $height, $type, $attr) = getimagesize($generation_path . '/' . $file_name . ".$ext");
                            if (( $min_width > $width || $min_height > $height ) && $ext != 'svg') {
                                $success = 0;
                                $message = sprintf(__('Uploaded file dimensions: %1$spx x %2$spx, minimum required ', 'pcd'), $width, $height);
                                if ($min_width > 0 && $min_height > 0) {
                                    $message .= __('dimensions:', 'pcd') . " $min_height" . 'px' . " x $min_height" . 'px';
                                } elseif ($min_width > 0) {
                                    $message .= "width: $min_width" . 'px';
                                } elseif ($min_height > 0) {
                                    $message .= "height: $min_height" . 'px';
                                }
                            } else {
                                $success = 1;
                                $img_url = "$generation_url/$file_name.$ext";
				$message = '<li class="clipart-img ' . $class . '"><span class="pcd-del-img fa fa-close'.$del_class.'"></span><img alt="image" src="' . $generation_url . '/' . $file_name . '.' . $ext . '" data-upload-id="' . $img_id . ' data-url=' . $img_url . '" data-img-name="' . $name . '"/></li>';
                            }
                        } else {
                            $success = 1;
                            $img_url = "$generation_url/$file_name.$ext";
				$message = '<li class="clipart-img ' . $class . '"><span class="pcd-del-img fa fa-close'.$del_class.'"></span><img alt="image" src="' . $generation_url . '/' . $file_name . '.' . $ext . '" data-upload-id="' . $img_id . '" data-url="' . $img_url . '" data-img-name="' . $name . '"/></li>';
                        }
                        if ($success == 0) {
                            unlink($generation_path . '/' . $file_name . ".$ext");
                        }
                    } else {
                        $success = 0;
                        $message = __('An error occured during the upload. Please try again later', 'pcd');
                    }
                } else {
                    $success = 0;
                    $message = __('Incorrect file extension: ' . $ext . '. Allowed extensions: ', 'pcd') . implode(', ', $valid_formats);
                }

                if ($success === 1) {
                    $new_pcd_upload = array(
                        'img_url' => $img_url,
                        'img_id' => $img_id,
                        'img_name' => $name = $_FILES['userfile']['name'],
                    );
                    $bg_or_upload_slug = '';
                    if (!$is_bg_upload) {
                        $bg_or_upload_slug = 'pcd-upload';
                    } else {
                        $bg_or_upload_slug = 'pcd-bg-upload';
                    }
                    if (!is_user_logged_in()) {

                        if (isset($_COOKIE[$bg_or_upload_slug]) && !empty($_COOKIE[$bg_or_upload_slug])) {
                            $pcd_upload_json = json_decode(base64_decode($_COOKIE[$bg_or_upload_slug]),true);
                            if (null === $pcd_upload_json) {
                                $pcd_upload = array();
                            } else {
                                $pcd_upload = $pcd_upload_json;
                            }
                        } else {
                            $pcd_upload = array();
                        }
                        array_push($pcd_upload, $new_pcd_upload);
                        $pcd_upload_json = base64_encode(json_encode($pcd_upload));
                        setcookie($bg_or_upload_slug, $pcd_upload_json, time() + 365 * 24 * 3600, '/');
                    } else {
                        global $current_user;
                        $current_user_id = $current_user->ID;
                        $user_uploads = get_user_meta($current_user_id, $bg_or_upload_slug);
                        if (empty($user_uploads)) {
                            $user_uploads = array();
                        } else {
                            $user_uploads = $user_uploads[0];
                        }
                        $user_uploads[] = $new_pcd_upload;
                        update_user_meta($current_user_id, $bg_or_upload_slug, $user_uploads);
                    }
                }
                echo json_encode(
                        array(
                            'success' => $success,
                            'message' => $message,
                            'img_url' => $img_url,
                            'img_id' => $img_id,
                            'is_bg_upload' => $is_bg_upload
                        )
                );
            }
        }
        die();
    }

    /**
     * Handle delete picture upload.
     * 
     * @global type $current_user
     */
    public function pcd_handle_delete_picture_upload() {
        $success = 0;
        $element_key = '';
        $img_id = filter_input(INPUT_POST, 'img_id');
        $img_url = filter_input(INPUT_POST, 'img_url');
        $img_name = filter_input(INPUT_POST, 'img_name');
        $is_bg_delete = filter_input(INPUT_POST, 'is_bg_delete');
        if (!$is_bg_delete) {
            $bg_or_upload_slug = 'pcd-upload';
        } else {
            $bg_or_upload_slug = 'pcd-bg-upload';
        }
	
        if (!is_user_logged_in()) {
	    
            if (isset($_COOKIE[$bg_or_upload_slug]) && !empty($_COOKIE[$bg_or_upload_slug])) {
                $pcd_upload_json = json_decode(base64_decode($_COOKIE[$bg_or_upload_slug]),true);
                if (null === $pcd_upload_json) {
                    $pcd_upload = array();
                } else {
                    $pcd_upload = $pcd_upload_json;
                }
            } else {
                $pcd_upload = array();
            }
	    
            if (is_array($pcd_upload) && !empty($pcd_upload)) {
                foreach ($pcd_upload as $key => $value) {
		    
                    if ($value['img_id'] == $img_id && $value['img_name'] == $img_name && $value['img_url'] == $img_url) {
                        $element_key = $key;
                        break;
                    }
                }
            }
	    
            if (!empty($element_key) || 0 === $element_key) {
                unset($pcd_upload[$element_key]);
		
                //array_splice( $pcd_upload, $element_key );
                $pcd_upload_json = base64_encode(json_encode($pcd_upload));
                setcookie($bg_or_upload_slug, $pcd_upload_json, time() + 365 * 24 * 3600, '/');
                $success = 1;
            } else {
                $success = 0;
            }
        } else {
            global $current_user;
            $current_user_id = $current_user->ID;
            $user_uploads = get_user_meta($current_user_id, $bg_or_upload_slug);
            if (empty($user_uploads)) {
                $user_uploads = array();
            } else {
                $user_uploads = $user_uploads[0];
            }
            if (is_array($user_uploads) && !empty($user_uploads)) {
                foreach ($user_uploads as $key => $value) {
                    if ($value['img_id'] == $img_id && $value['img_name'] == $img_name && $value['img_url'] == $img_url) {
                        $element_key = $key;
                        break;
                    }
                }
            }
            if (!empty($element_key) || 0 === $element_key) {
                unset($user_uploads[$element_key]);
                //array_splice( $user_uploads, $element_key );
                update_user_meta($current_user_id, $bg_or_upload_slug, $user_uploads);
                $success = 1;
            } else {
                $success = 0;
            }
        }
        echo json_encode($success);
        die();
    }

    /**
     * Move user picture uploads.
     *
     * @param type $user_id The user id.
     */
    public function move_user_picture_uplaods($user_id) {
        $user_uploads = array();
        $bg_or_upload_slug = [];
        $bg_or_upload_slug[] = 'pcd-upload';
        $bg_or_upload_slug[] = 'pcd-bg-upload';
        foreach ($bg_or_upload_slug as $value) {
            if (isset($_COOKIE[$value]) && !empty($_COOKIE[$value])) {
                $pcd_upload_json = json_decode(base64_decode($_COOKIE[$value]));
                if (null === $pcd_upload_json) {
                    $pcd_upload = array();
                } else {
                    $pcd_upload = $pcd_upload_json;
                }
            } else {
                $pcd_upload = array();
            }
            foreach ($pcd_upload as $image) {
                $user_upload = array();
                if (isset($image->img_id) && !empty($image->img_id)) {
                    $user_upload['img_id'] = $image->img_id;
                }
                if (isset($image->img_url) && !empty($image->img_url)) {
                    $user_upload['img_url'] = $image->img_url;
                }
                if (isset($image->img_name) && !empty($image->img_name)) {
                    $user_upload['img_name'] = $image->img_name;
                }

                array_push($user_uploads, $user_upload);
            }
            add_user_meta($user_id, $value, $user_uploads);
        }
    }

    /**
     * Process social login.
     */
    public function process_social_login() {
        if (isset($_GET['social-login'])) {
            $login_type = $_GET['social-login'];
            $allowed_logins = array('facebook', 'instagram');
            if (in_array($login_type, $allowed_logins)) {
                require_once PCD_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'hybridauth' . DIRECTORY_SEPARATOR . 'Hybrid' . DIRECTORY_SEPARATOR . 'Auth.php';
                require_once PCD_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'hybridauth' . DIRECTORY_SEPARATOR . 'Hybrid' . DIRECTORY_SEPARATOR . 'thirdparty' . DIRECTORY_SEPARATOR . 'Facebook' . DIRECTORY_SEPARATOR . 'facebook.php';
                $config = PCD_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'hybridauth' . DIRECTORY_SEPARATOR . 'config.php';
                try {
                    $hybridauth = new Hybrid_Auth($config);

                    $adapter = $hybridauth->authenticate($login_type);

                    if ($login_type == 'facebook') {
                        $token = Hybrid_Auth::storage()->get('hauth_session.facebook.token.access_token');
                        $api = $adapter->api();
                        $uploaded_data = $api->get('/me/photos/uploaded/?fields=id,name,picture,images', $token);
                        $tagged_data = $api->get('/me/photos/?fields=id,name,picture,images', $token);
                        //Fusionner $uploaded_data et $tagged_data.
                        $_SESSION['pcd-facebook-images'] = array();
                        $decoded_uploaded_data_body = $uploaded_data->getDecodedBody();
                        foreach ($decoded_uploaded_data_body as $x) {
                            foreach ($x as $i => $y) {
                                if (isset($y['images'])) {
                                    $max_width = 0;
                                    foreach ($y['images'] as $z) {
                                        if (isset($z['source']) && !empty($z['source'])) {
                                            if (( strpos($z['source'], '.jpg') ) && $z['width'] > $max_width) {
                                                //list($width, $height, $type, $attr) = getimagesize( $z['source'] );
                                                $_SESSION['pcd-facebook-images'][$i] = $z['source'];
                                                $max_width = $z['width'];
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        $decoded_tagged_data_body = $tagged_data->getDecodedBody();
                        foreach ($decoded_tagged_data_body as $x) {
                            foreach ($x as $i => $y) {
                                if (isset($y['images'])) {
                                    $max_width = 0;
                                    foreach ($y['images'] as $z) {
                                        if (isset($z['source']) && !empty($z['source'])) {
                                            if (( strpos($z['source'], '.jpg') ) && $z['width'] > $max_width) {
                                                $_SESSION['pcd-facebook-images'][$i] = $z['source'];
                                                $max_width = $z['width'];
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    } elseif ($login_type == 'instagram') {
                        $_SESSION['pcd-instagram-images'] = array();
                        $uploaded_data = $adapter->api()->api('users/self/media/recent/');
                        foreach ($uploaded_data->data as $data) {
                            if ($data->type == 'image') {
                                //list($width, $height, $type, $attr) = getimagesize( $z['source'] );
                                array_push($_SESSION['pcd-instagram-images'], $data->images->standard_resolution->url);
                            }
                        }
                    }
                } catch (Exception $e) {
                    die('<b>got an error!</b> ' . $e->getMessage());
                }
            }
        }
    }

}
